@@ -153,8 +153,8 @@ void DkInstallUpdater::checkForUpdates(bool silent) {
 
 	mSilent = silent;
 
-	Settings::param().sync().lastUpdateCheck = QDate::currentDate();
-	Settings::param().save();
+	DkSettingsManager::param().sync().lastUpdateCheck = QDate::currentDate();
+	DkSettingsManager::param().save();
 
 	QUrl url ("http://download.nomacs.org/repository/Updates.xml");
 
@@ -246,7 +246,7 @@ void DkInstallUpdater::replyFinished(QNetworkReply* reply) {
 			update = result == QMessageBox::Accepted || result == QMessageBox::Yes;
 
 			if (result == QMessageBox::No)	// do not show again
-				Settings::param().sync().updateDialogShown = true;	
+				DkSettingsManager::param().sync().updateDialogShown = true;	
 
 			msgBox->deleteLater();
 		}
@@ -308,17 +308,17 @@ DkUpdater::DkUpdater(QObject* parent) : QObject(parent) {
 
 void DkUpdater::checkForUpdates() {
 
-	Settings::param().sync().lastUpdateCheck = QDate::currentDate();
-	Settings::param().save();
+	DkSettingsManager::param().sync().lastUpdateCheck = QDate::currentDate();
+	DkSettingsManager::param().save();
 
 #ifdef Q_OS_WIN
-	QUrl url ("http://www.nomacs.org/version_win_stable");
+	QUrl url ("http://www.nomacs.org/version/version_win_stable");
 #elif defined Q_OS_LINUX
-	QUrl url ("http://www.nomacs.org/version_linux");
+	QUrl url ("http://www.nomacs.org/version/version_linux");
 #elif defined Q_OS_MAC
-	QUrl url ("http://www.nomacs.org/version_mac_stable");
+	QUrl url ("http://www.nomacs.org/version/version_mac_stable");
 #else
-	QUrl url ("http://www.nomacs.org/version");
+	QUrl url ("http://www.nomacs.org/version/version");
 #endif
 
 	// the proxy settings take > 2 sec on Win7
@@ -338,8 +338,6 @@ void DkUpdater::checkForUpdates() {
 
 	qDebug() << "checking for updates";
 	connect(&mAccessManagerVersion, SIGNAL(finished(QNetworkReply*)), this, SLOT(replyFinished(QNetworkReply*)));	
-	QNetworkRequest request = QNetworkRequest(url);
-	request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysNetwork);
 	mReply = mAccessManagerVersion.get(QNetworkRequest(url));
 	connect(mReply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(replyError(QNetworkReply::NetworkError)));
 }
@@ -398,11 +396,11 @@ void DkUpdater::replyFinished(QNetworkReply* reply) {
 		}
 
 		if (nVersion[0].toInt() > cVersion[0].toInt()  ||	// major release
-			(nVersion[0].toInt() == cVersion[0].toInt() &&	// major release
-				nVersion[1].toInt() > cVersion[1].toInt())  ||	// minor release
-			(nVersion[0].toInt() == cVersion[0].toInt() &&	// major release
-				nVersion[1].toInt() == cVersion[1].toInt()) &&	// minor release
-			nVersion[2].toInt() >  cVersion[2].toInt()) {	// minor-minor release
+		   (nVersion[0].toInt() == cVersion[0].toInt() &&	// major release
+			nVersion[1].toInt() > cVersion[1].toInt())  ||	// minor release
+		   (nVersion[0].toInt() == cVersion[0].toInt() &&	// major release
+			nVersion[1].toInt() == cVersion[1].toInt() &&	// minor release
+			nVersion[2].toInt() >  cVersion[2].toInt())) {	// minor-minor release
 
 			QString msg = tr("A new version") + " (" + sl[0] + ") " + tr("is available");
 			msg = msg + "<br>" + tr("Do you want to download and install it now?");
@@ -468,9 +466,9 @@ void DkUpdater::downloadFinishedSlot(QNetworkReply* data) {
 
 		file.close();
 
-		Settings::param().global().setupVersion = mSetupVersion;
-		Settings::param().global().setupPath = absoluteFilePath;
-		Settings::param().save();
+		DkSettingsManager::param().global().setupVersion = mSetupVersion;
+		DkSettingsManager::param().global().setupPath = absoluteFilePath;
+		DkSettingsManager::param().save();
 
 		emit downloadFinished(absoluteFilePath);
 	}
@@ -522,17 +520,13 @@ void DkTranslationUpdater::checkForUpdates() {
 		mAccessManager.setProxy(listOfProxies[0]);
 	}
 
-	QUrl url ("http://www.nomacs.org/translations/" + Settings::param().global().language + "/nomacs_" + Settings::param().global().language + ".qm");
+	QUrl url ("http://nomacs.org/translations/" + DkSettingsManager::param().global().language + "/nomacs_" + DkSettingsManager::param().global().language + ".qm");
 	qDebug() << "checking for new translations at " << url;
-	QNetworkRequest request = QNetworkRequest(url);
-	request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysNetwork);
 	mReply = mAccessManager.get(QNetworkRequest(url));
 	connect(mReply, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateDownloadProgress(qint64, qint64)));
 
-	url=QUrl("http://www.nomacs.org/translations/qt/qt_" + Settings::param().global().language + ".qm");
+	url=QUrl("http://nomacs.org/translations/qt/qt_" + DkSettingsManager::param().global().language + ".qm");
 	qDebug() << "checking for new translations at " << url;
-	request = QNetworkRequest(url);
-	request.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysNetwork);
 	mReplyQt = mAccessManager.get(QNetworkRequest(url));
 	connect(mReplyQt, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateDownloadProgressQt(qint64, qint64)));
 }
@@ -563,7 +557,7 @@ void DkTranslationUpdater::replyFinished(QNetworkReply* reply) {
 
 #ifdef  Q_OS_WIN
 	QDir storageLocation;
-	if (Settings::param().isPortable()) {
+	if (DkSettingsManager::param().isPortable()) {
 		storageLocation = QDir(QCoreApplication::applicationDirPath());
 		storageLocation.cd("translations");
 	}
@@ -578,10 +572,10 @@ void DkTranslationUpdater::replyFinished(QNetworkReply* reply) {
 
 #endif //  Q_OS_WIN
 
-	QString translationName = qtTranslation ? "qt_"+ Settings::param().global().language + ".qm" : "nomacs_"+ Settings::param().global().language + ".qm";
+	QString translationName = qtTranslation ? "qt_"+ DkSettingsManager::param().global().language + ".qm" : "nomacs_"+ DkSettingsManager::param().global().language + ".qm";
 
 	if (isRemoteFileNewer(lastModifiedRemote, translationName)) {
-		QString basename = qtTranslation ? "qt_" + Settings::param().global().language : "nomacs_" + Settings::param().global().language;
+		QString basename = qtTranslation ? "qt_" + DkSettingsManager::param().global().language : "nomacs_" + DkSettingsManager::param().global().language;
 		QString extension = ".qm";
 
 		if (!storageLocation.exists()) {
@@ -629,7 +623,8 @@ void DkTranslationUpdater::updateDownloadProgress(qint64 received, qint64 total)
 		return;
 
 	QDateTime lastModifiedRemote = mReply->header(QNetworkRequest::LastModifiedHeader).toDateTime();
-	QString translationName = "nomacs_"+ Settings::param().global().language + ".qm";
+
+	QString translationName = "nomacs_"+ DkSettingsManager::param().global().language + ".qm";
 	qDebug() << "isRemoteFileNewer:" << isRemoteFileNewer(lastModifiedRemote, translationName);
 	if (!isRemoteFileNewer(lastModifiedRemote, translationName)) {
 		updateAborted = true;
@@ -650,7 +645,7 @@ void DkTranslationUpdater::updateDownloadProgressQt(qint64 received, qint64 tota
 		return;
 
 	QDateTime lastModifiedRemote = mReplyQt->header(QNetworkRequest::LastModifiedHeader).toDateTime();
-	QString translationName = "qt_"+ Settings::param().global().language + ".qm";
+	QString translationName = "qt_"+ DkSettingsManager::param().global().language + ".qm";
 	qDebug() << "isRemoteFileNewer:" << isRemoteFileNewer(lastModifiedRemote, translationName);
 	if (!isRemoteFileNewer(lastModifiedRemote, translationName)) {
 		updateAbortedQt = true;
@@ -672,7 +667,7 @@ bool DkTranslationUpdater::isRemoteFileNewer(QDateTime lastModifiedRemote, const
 
 #ifdef  Q_OS_WIN
 	QDir storageLocation;
-	if (Settings::param().isPortable()) {
+	if (DkSettingsManager::param().isPortable()) {
 		storageLocation = QDir(QCoreApplication::applicationDirPath());
 		storageLocation.cd("translations");
 	}
