@@ -1,3 +1,4 @@
+#include "DkUtils.h"
 /*******************************************************************************************************
  DkUtils.cpp
  Created on:	09.03.2010
@@ -33,6 +34,10 @@
 #include <sys/sysinfo.h>
 #endif
 
+#ifndef WITH_OPENCV
+#include <cassert>
+#endif
+
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <QString>
 #include <QFileInfo>
@@ -52,7 +57,11 @@
 #include <QStandardPaths>
 #include <QApplication>
 #include <QMainWindow>
+#include <QMouseEvent>
 #include <qmath.h>
+#include <QMimeDatabase>
+
+#include <QSystemSemaphore>
 #pragma warning(pop)		// no warnings from includes - end
 
 #if defined(Q_OS_WIN) && !defined(SOCK_STREAM)
@@ -84,7 +93,7 @@ namespace nmc {
 void qtMessageOutput(QtMsgType type, const QMessageLogContext &, const QString &msg) {
 
 #if QT_VERSION >= 0x050500
-	if (!Settings::param().app().useLogFile)
+	if (!DkSettingsManager::param().app().useLogFile)
 		return;	// should not be called anyhow
 
 	static QString filePath;
@@ -274,6 +283,57 @@ bool DkUtils::naturalCompare(const QString &s1, const QString &s2, Qt::CaseSensi
 	return QString::compare(s1, s2, cs) < 0;
 }
 
+/// <summary>
+/// Resolves symbolic links.
+/// </summary>
+/// <param name="filePath">The file path of the (potential) sym link.</param>
+/// <returns>If the file is no link, its path is returned.</returns>
+QString DkUtils::resolveSymLink(const QString & filePath) {
+	
+	QString rFilePath = filePath;
+
+	QFileInfo fInfo(filePath);
+
+	if (fInfo.isSymLink()) {
+		rFilePath = fInfo.symLinkTarget();
+	}
+	// check if files < 1 kb contain a link
+	else if (fInfo.size() < 1000) {
+
+		QFile file(filePath);
+
+		// silently ignore not readable files here
+		if (file.open(QIODevice::ReadOnly)) {
+
+			QTextStream txt(&file);
+
+			while (!txt.atEnd()) {
+
+				// is there an absolute path?
+				QString cl = txt.readLine();
+
+				if (cl.isEmpty())
+					continue;
+
+				QFileInfo fi(cl);
+				if (fi.exists()) {
+					rFilePath = fi.absoluteFilePath();
+					break;
+				}
+
+				// is there a relative path?
+				fi = QFileInfo(fInfo.absolutePath() + QDir::separator() + cl);
+				if (fi.exists() & fi.isFile()) {
+					rFilePath = fi.absoluteFilePath();
+					break;
+				}
+			}
+		}
+	}
+
+	return rFilePath;
+}
+
 QString DkUtils::getLongestNumber(const QString& str, int startIdx) {
 
 	int idx;
@@ -327,7 +387,7 @@ void DkUtils::addLanguages(QComboBox* langCombo, QStringList& languages) {
 	QDir qmDir = qApp->applicationDirPath();
 
 	// find all translations
-	QStringList translationDirs = Settings::param().getTranslationDirs();
+	QStringList translationDirs = DkSettingsManager::param().getTranslationDirs();
 	QStringList fileNames;
 
 	for (int idx = 0; idx < translationDirs.size(); idx++) {
@@ -343,7 +403,7 @@ void DkUtils::addLanguages(QComboBox* langCombo, QStringList& languages) {
 		locale.chop(3);
 
 		QTranslator translator;
-		Settings::param().loadTranslation(fileNames[i], translator);
+		DkSettingsManager::param().loadTranslation(fileNames[i], translator);
 
 		//: this should be the name of the language in which nomacs is translated to
 		QString language = translator.translate("nmc::DkGlobalSettingsWidget", "English");
@@ -354,7 +414,7 @@ void DkUtils::addLanguages(QComboBox* langCombo, QStringList& languages) {
 		languages << locale;
 	}
 
-	langCombo->setCurrentIndex(languages.indexOf(Settings::param().global().language));
+	langCombo->setCurrentIndex(languages.indexOf(DkSettingsManager::param().global().language));
 	if (langCombo->currentIndex() == -1) // set index to English if language has not been found
 		langCombo->setCurrentIndex(0);
 
@@ -418,7 +478,7 @@ void DkUtils::registerFileVersion() {
 
 void DkUtils::initializeDebug() {
 
-	if (Settings::param().app().useLogFile)
+	if (DkSettingsManager::param().app().useLogFile)
 		qInstallMessageHandler(qtMessageOutput);
 
 	// format console
@@ -524,30 +584,65 @@ QFileInfo DkUtils::urlToLocalFile(const QUrl& url) {
 }
 
 /**
- * Returns if a file is supported by nomacs or not.
- * Note: this function only checks for a valid extension.
+ * @brief isValidByContent identifies a file by file content.
+ * @param file is an existing file.
+ * @return true, if file exists and has content we support, false otherwise.
+ */
+bool isValidByContent(const QFileInfo& file) {
+
+    if(!file.exists()) return false;
+    if(!file.isFile()) return false;
+
+    QMimeDatabase mimeDb;
+    QMimeType fileMimeType = mimeDb.mimeTypeForFile(file, QMimeDatabase::MatchContent);
+
+    for(QString sfx: fileMimeType.suffixes()) {
+        QString tryFilename = file.fileName() + QString(".") + sfx;
+
+        if(DkUtils::hasValidSuffix(tryFilename)) {
+            return true;
+        }
+    }
+    return false;
+}
+
+/**
+ * @brief: return if a file is supported by nomacs or not.
  * @param fileInfo the file info of the file to be validated.
  * @return bool true if the file format is supported.
  **/
 bool DkUtils::isValid(const QFileInfo& fileInfo) {
 
-	printf("accepting file...\n");
-
 	QFileInfo fInfo = fileInfo;
+	QString fileName = fInfo.fileName();
+
 	if (fInfo.isSymLink())
 		fInfo = fileInfo.symLinkTarget();
 
-	if (!fInfo.exists())
-		return false;
+	bool fileIsValid = false;
+	auto printDebug = [&](QString msg){
+		QString validText = fileIsValid?"is valid":"is invalid";
+		qDebug() << QString("file %1 %2 %3").arg(fileName).arg(validText).arg(msg);
+	};
 
-	QString fileName = fInfo.fileName();
+    if (!fInfo.exists()) {
+        fileIsValid = false;
+        printDebug("doesn't exist");
 
-	return hasValidSuffix(fileName);
+    } else if(hasValidSuffix(fInfo.fileName()))  {
+        fileIsValid = true;
+        printDebug("is has no valid extension.");
+
+    } else if(isValidByContent(fInfo))  {
+        fileIsValid = true;
+        printDebug("detected by mime");
+    }
+    return fileIsValid;
 }
 
 bool DkUtils::isSavable(const QString & fileName) {
 	
-	QStringList cleanSaveFilters = suffixOnly(Settings::param().app().saveFilters);
+	QStringList cleanSaveFilters = suffixOnly(DkSettingsManager::param().app().saveFilters);
 
 	for (const QString& cFilter : cleanSaveFilters) {
 
@@ -565,9 +660,9 @@ bool DkUtils::isSavable(const QString & fileName) {
 
 bool DkUtils::hasValidSuffix(const QString& fileName) {
 
-	for (int idx = 0; idx < Settings::param().app().fileFilters.size(); idx++) {
+	for (int idx = 0; idx < DkSettingsManager::param().app().fileFilters.size(); idx++) {
 
-		QRegExp exp = QRegExp(Settings::param().app().fileFilters.at(idx), Qt::CaseInsensitive);
+		QRegExp exp = QRegExp(DkSettingsManager::param().app().fileFilters.at(idx), Qt::CaseInsensitive);
 		exp.setPatternSyntax(QRegExp::Wildcard);
 		if (exp.exactMatch(fileName))
 			return true;
@@ -640,7 +735,7 @@ QDateTime DkUtils::convertDate(const QString& date, const QFileInfo& file) {
 		dateCreated = file.created();
 
 	return dateCreated;
-};
+}
 
 QString DkUtils::convertDateString(const QString& date, const QFileInfo& file) {
 
@@ -721,6 +816,10 @@ QStringList DkUtils::filterStringList(const QString& query, const QStringList& l
 	QStringList resultList = list;
 
 	for (int idx = 0; idx < queries.size(); idx++) {
+		// Detect and correct special case where a space is leading or trailing the search term - this should be significant
+		if (idx == 0 && queries.size() > 1 && queries[idx].size() == 0) queries[idx] = " " + queries[idx + 1];
+		if (idx == queries.size() - 1 && queries.size() > 2 && queries[idx].size() == 0) queries[idx] = queries[idx - 1] + " ";
+		// The queries will be repeated, but this is okay - it will just be matched both with and without the space. 
 		resultList = resultList.filter(queries[idx], Qt::CaseInsensitive);
 		qDebug() << "query: " << queries[idx];
 	}
@@ -894,6 +993,21 @@ QString DkUtils::resolveFraction(const QString& frac) {
 	return result;
 }
 
+QList<QUrl> DkUtils::findUrlsInTextNewline(QString text){
+    QList<QUrl> urls;
+    QStringList lines = text.split(QRegExp("\n|\r\n|\r"));
+    for(QUrl maybeUrl: QUrl::fromStringList(lines)){
+        if(maybeUrl.isValid()){
+            if(maybeUrl.isRelative()){
+                maybeUrl.setScheme("file");
+            }
+            urls.append(maybeUrl);
+        }
+    }
+    return urls;
+}
+
+
 // code from: http://stackoverflow.com/questions/5625884/conversion-of-stdwstring-to-qstring-throws-linker-error
 std::wstring DkUtils::qStringToStdWString(const QString &str) {
 #ifdef _MSC_VER
@@ -1041,12 +1155,53 @@ void TreeItem::clear() {
 	childItems.clear();
 }
 
-void TreeItem::appendChild(TreeItem *item) {
-	childItems.append(item);
-	//item->setParent(this);
+void TreeItem::remove(int rowIdx) {
+	
+	if (rowIdx < childCount()) {
+		delete childItems[rowIdx];
+		childItems.remove(rowIdx);
+	}
 }
 
-TreeItem* TreeItem::child(int row) {
+void TreeItem::appendChild(TreeItem *item) {
+	childItems.append(item);
+}
+
+bool TreeItem::contains(const QRegExp& regExp, int column, bool recursive) const {
+
+	bool found = false;
+
+	if (column == -1) {
+
+		for (int idx = 0; idx < columnCount(); idx++)
+			if (contains(regExp, idx))
+				return true;
+
+		return false;
+	}
+
+	found = data(column).toString().contains(regExp);
+
+	// if the parent contains the key, I am valid too
+	TreeItem* p = parent();
+	if (!found && p)
+		found = p->contains(regExp, column, false);	// the parent must not check its kid's again
+
+	// if a child contains the key, I am valid too
+	if (!found && recursive) {
+		for (int idx = 0; idx < childCount(); idx++) {
+			assert(child(idx));
+			found = child(idx)->contains(regExp, column, recursive);
+
+			if (found)
+				break;
+		}
+	}
+
+	return found;
+}
+
+TreeItem* TreeItem::child(int row) const {
 
 	if (row < 0 || row >= childItems.size())
 		return 0;
@@ -1077,6 +1232,10 @@ int TreeItem::columnCount() const {
 }
 
 QVariant TreeItem::data(int column) const {
+	
+	if (column >= itemData.size())
+		return QVariant();
+	
 	return itemData.value(column);
 }
 
@@ -1085,7 +1244,7 @@ void TreeItem::setData(const QVariant& value, int column) {
 	if (column < 0 || column >= itemData.size())
 		return;
 
-	qDebug() << "replacing: " << itemData[0] << " with: " << value;
+	//qDebug() << "replacing: " << itemData[0] << " with: " << value;
 	itemData.replace(column, value);
 }
 
@@ -1104,6 +1263,22 @@ TreeItem* TreeItem::find(const QVariant& value, int column) {
 	return 0;
 }
 
+QStringList TreeItem::parentList() const {
+
+	QStringList pl;
+	parentList(pl);
+
+	return pl;
+}
+
+void TreeItem::parentList(QStringList& parentKeys) const {
+
+	if (parent()) {
+		parent()->parentList(parentKeys);
+		parentKeys << parent()->data(0).toString();
+	}
+}
+
 TreeItem* TreeItem::parent() const {
 	return parentItem;
 }
@@ -1112,5 +1287,70 @@ void TreeItem::setParent(TreeItem* parent) {
 	parentItem = parent;
 }
 
+bool TabMiddleMouseCloser::eventFilter(QObject *obj, QEvent *event) {
+	if (event->type() == QEvent::MouseButtonRelease) {
+		QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
+		if (mouseEvent->button() == Qt::MidButton) {
+			auto tabbar = static_cast<QTabBar *>(obj);
+			for (int i = 0; i < tabbar->count(); i++) {
+				QRect tabrect = tabbar->tabRect(i);
+				if (tabrect.contains(mouseEvent->pos()))
+					callback(i);
+			}
+			return true;
+		}	
+	}
+
+
+	return QObject::eventFilter(obj, event);
+}
+
+// DkRunGuard --------------------------------------------------------------------
+DkRunGuard::DkRunGuard() : mSharedMem(mSharedMemKey) {
+
+	QSystemSemaphore lock(mLockKey, 1);
+	lock.acquire();
+
+	{
+		// this fixes unix issues if the first instance crashes
+		// see here for details: https://habrahabr.ru/post/173281/
+		QSharedMemory fix(mSharedMemKey);
+		fix.attach();
+	}
+
+	lock.release();
+}
+
+DkRunGuard::~DkRunGuard() {
+
+	QSystemSemaphore lock(mLockKey, 1);
+	lock.acquire();
+
+	if (mSharedMem.isAttached())
+		mSharedMem.detach();
+
+	lock.release();
+}
+
+/// <summary>
+/// Checks if this instance is the first running.
+/// If it's the first instance, a shared memory block is created.
+/// </summary>
+/// <returns>true if this is the first instance</returns>
+bool DkRunGuard::tryRunning() {
+
+	QSystemSemaphore lock(mLockKey, 1);
+	lock.acquire();
+
+	// check if we can attach to the shared memory
+	// if not: we are the first
+	bool attached = mSharedMem.attach();
+	if (!attached)
+		mSharedMem.create(sizeof(quint64));
+
+	lock.release();
+
+	return !attached;
+}
 
 }
