@@ -54,6 +54,7 @@
 #include <QDesktopWidget>
 #include <QDragEnterEvent>
 #include <QStandardPaths>
+#include <QInputDialog>
 #pragma warning(pop)		// no warnings from includes - end
 
 namespace nmc {
@@ -68,6 +69,7 @@ DkTabInfo::DkTabInfo(const QSharedPointer<DkImageContainerT> imgC, int idx, QObj
 
 	mTabMode = (!imgC) ? tab_recent_files : tab_single_image;
 	mTabIdx = idx;
+	mFilePath = getFilePath();
 }
 
 DkTabInfo::DkTabInfo(TabMode mode, int idx, QObject* parent) : QObject(parent) {
@@ -80,7 +82,7 @@ DkTabInfo::DkTabInfo(TabMode mode, int idx, QObject* parent) : QObject(parent) {
 }
 
 DkTabInfo::~DkTabInfo() {
-	qDebug() << "tab at: " << mTabIdx << " released...";
+	//qDebug() << "tab at: " << mTabIdx << " released...";
 }
 
 bool DkTabInfo::operator ==(const DkTabInfo& o) const {
@@ -91,7 +93,13 @@ bool DkTabInfo::operator ==(const DkTabInfo& o) const {
 void DkTabInfo::loadSettings(const QSettings& settings) {
 
 	QString file = settings.value("tabFileInfo", "").toString();
-	mTabMode = settings.value("tabMode", tab_single_image).toInt();
+	int tabSetting = settings.value("tabMode", tab_single_image).toInt();
+
+	if(tabSetting < TabMode::tab_end){
+		mTabMode = static_cast<enum TabMode>(tabSetting);
+	}else{
+		mTabMode = tab_single_image;
+	}
 
 	if (QFileInfo(file).exists())
 		mImageLoader->setCurrentImage(QSharedPointer<DkImageContainerT>(new DkImageContainerT(file)));
@@ -113,17 +121,28 @@ void DkTabInfo::saveSettings(QSettings& settings) const {
 void DkTabInfo::setFilePath(const QString& filePath) {
 
 	mImageLoader->setCurrentImage(QSharedPointer<DkImageContainerT>(new DkImageContainerT(filePath)));
+	setMode(tab_single_image);
+	mFilePath = filePath;
 }
 
-void DkTabInfo::setDirPath(const QString& dirPath) {
+bool DkTabInfo::setDirPath(const QString& dirPath) {
 	
-	mImageLoader->loadDir(dirPath);
-	setMode(tab_thumb_preview);
+	QFileInfo di(dirPath);
+	if(!di.isDir())
+		return false;
+
+	bool dirIsLoaded = mImageLoader->loadDir(dirPath);
+	if(dirIsLoaded) {
+		setMode(tab_thumb_preview);
+		return true;
+	}
+
+	return false;
 }
 
 QString DkTabInfo::getFilePath() const {
 
-	return (mImageLoader->getCurrentImage()) ? mImageLoader->getCurrentImage()->filePath() : QString();
+	return (mImageLoader->getCurrentImage()) ? mImageLoader->getCurrentImage()->filePath() : mFilePath;
 }
 
 void DkTabInfo::setTabIdx(int tabIdx) {
@@ -142,6 +161,7 @@ void DkTabInfo::setImage(QSharedPointer<DkImageContainerT> imgC) {
 	
 	if (imgC)
 		mTabMode = tab_single_image;
+	mFilePath = getFilePath();
 }
 
 QSharedPointer<DkImageLoader> DkTabInfo::getImageLoader() const {
@@ -223,16 +243,18 @@ QString DkTabInfo::getTabText() const {
 	return tabText;
 }
 
-int DkTabInfo::getMode() const {
+enum DkTabInfo::TabMode DkTabInfo::getMode() const {
 
 	return mTabMode;
 }
 
 void DkTabInfo::setMode(int mode) {
 
-	mTabMode = mode;
+	if(mode < TabMode::tab_end)
+		mTabMode = static_cast<enum TabMode>(mode);
 }
 
+// DkCenteralWidget --------------------------------------------------------------------
 DkCentralWidget::DkCentralWidget(DkViewPort* viewport, QWidget* parent) : QWidget(parent) {
 
 	mViewport = viewport;
@@ -242,11 +264,21 @@ DkCentralWidget::DkCentralWidget(DkViewPort* viewport, QWidget* parent) : QWidge
 	setAcceptDrops(true);
 
 	DkActionManager& am = DkActionManager::instance();
+	connect(am.action(DkActionManager::menu_file_new_tab), SIGNAL(triggered()), this, SLOT(addTab()));
+	connect(am.action(DkActionManager::menu_file_close_tab), SIGNAL(triggered()), this, SLOT(removeTab()));
+	connect(am.action(DkActionManager::menu_file_close_all_tabs), &QAction::triggered, this, [this]() { clearAllTabs(); });
 	connect(am.action(DkActionManager::menu_edit_paste), SIGNAL(triggered()), this, SLOT(pasteImage()));
-	connect(am.action(DkActionManager::menu_view_new_tab), SIGNAL(triggered()), this, SLOT(addTab()));
-	connect(am.action(DkActionManager::menu_view_close_tab), SIGNAL(triggered()), this, SLOT(removeTab()));
+	connect(am.action(DkActionManager::menu_view_first_tab), &QAction::triggered, this, [this]() { setActiveTab(0); });
 	connect(am.action(DkActionManager::menu_view_previous_tab), SIGNAL(triggered()), this, SLOT(previousTab()));
+	connect(am.action(DkActionManager::menu_view_goto_tab), &QAction::triggered, this, [this]() {
+		bool ok = false;
+		int idx = QInputDialog::getInt(this, tr("Go to Tab"), tr("Go to tab number: "), getActiveTab()+1, 1, getTabs().count(), 1, &ok);
+
+		if (ok)
+			setActiveTab(idx-1);
+	});
 	connect(am.action(DkActionManager::menu_view_next_tab), SIGNAL(triggered()), this, SLOT(nextTab()));
+	connect(am.action(DkActionManager::menu_view_last_tab), &QAction::triggered, this, [this]() { setActiveTab(getTabs().count()-1); });
 	connect(am.action(DkActionManager::menu_tools_batch), SIGNAL(triggered()), this, SLOT(openBatch()));
 	connect(am.action(DkActionManager::menu_panel_thumbview), SIGNAL(triggered(bool)), this, SLOT(showThumbView(bool)));
 }
@@ -261,12 +293,16 @@ void DkCentralWidget::createLayout() {
 
 	mTabbar = new QTabBar(this);
 	mTabbar->setShape(QTabBar::RoundedNorth);
+	mTabbar->setElideMode(Qt::TextElideMode::ElideRight);
+	mTabbar->setUsesScrollButtons(true);
 	mTabbar->setTabsClosable(true);
 	mTabbar->setMovable(true);
+	mTabbar->installEventFilter(new TabMiddleMouseCloser([this](int idx) { removeTab(idx); }));
 	mTabbar->hide();
 	//addTab(QFileInfo());
 
 	mProgressBar = new DkProgressBar(this);
+	//mProgressBar->setStyleSheet(mProgressBar->styleSheet() + "QProgressBar{background-color: #fff;}");
 	mProgressBar->hide();
 
 	mWidgets.resize(widget_end);
@@ -302,6 +338,7 @@ void DkCentralWidget::createLayout() {
 	// connections
 	connect(this, SIGNAL(loadFileSignal(const QString&)), this, SLOT(loadFile(const QString&)));
 	connect(mViewport, SIGNAL(addTabSignal(const QString&)), this, SLOT(addTab(const QString&)));
+	connect(mViewport, SIGNAL(showProgress(bool, int)), this, SLOT(showProgress(bool, int)));
 
 	connect(mTabbar, SIGNAL(currentChanged(int)), this, SLOT(currentTabChanged(int)));
 	connect(mTabbar, SIGNAL(tabCloseRequested(int)), this, SLOT(tabCloseRequested(int)));
@@ -319,7 +356,7 @@ void DkCentralWidget::createLayout() {
 
 void DkCentralWidget::saveSettings(bool saveTabs) const {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 
 	settings.beginGroup(objectName());
 	settings.remove("Tabs");
@@ -343,7 +380,7 @@ void DkCentralWidget::loadSettings() {
 
 	QVector<QSharedPointer<DkTabInfo> > tabInfos;
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 
 	settings.beginGroup(objectName());
 
@@ -424,11 +461,11 @@ void DkCentralWidget::currentTabChanged(int idx) {
 		mViewport->unloadImage();
 		mViewport->deactivate();
 
-		if (Settings::param().app().showRecentFiles)
+		if (DkSettingsManager::param().app().showRecentFiles)
 			showRecentFiles(true);
 	}
 
-	qDebug() << "[MARKUS] tab mode: " << mTabInfos.at(idx)->getMode();
+	//qDebug() << "[MARKUS] tab mode: " << mTabInfos.at(idx)->getMode();
 
 	//switchWidget(tabInfos.at(idx)->getMode());
 }
@@ -481,36 +518,44 @@ DkPreferenceWidget* DkCentralWidget::createPreferences() {
 	pw->addActions(am.helpActions().toList());
 	pw->addActions(am.hiddenActions().toList());
 
+	QSize s(22, 22);
+
 	// general preferences
-	DkPreferenceTabWidget* tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/settings.svg"), tr("General"), this);
+	DkPreferenceTabWidget* tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/settings.svg", s), tr("General"), this);
 	DkGeneralPreference* gp = new DkGeneralPreference(this);
 	tab->setWidget(gp);
 	pw->addTabWidget(tab);
 
 	// display preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/display-settings.svg"), tr("Display"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/display-settings.svg", s), tr("Display"), this);
 	DkDisplayPreference* dp = new DkDisplayPreference(this);
 	tab->setWidget(dp);
 	pw->addTabWidget(tab);
 
 	// file preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/dir.svg"), tr("File"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/dir.svg", s), tr("File"), this);
 	DkFilePreference* fp = new DkFilePreference(this);
 	tab->setWidget(fp);
 	pw->addTabWidget(tab);
 
 	// file association preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/nomacs.svg"), tr("File Associations"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/nomacs.svg", s), tr("File Associations"), this);
 	DkFileAssociationsPreference* fap = new DkFileAssociationsPreference(this);
 	tab->setWidget(fap);
 	pw->addTabWidget(tab);
 
-
 	// advanced preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/advanced-settings.svg"), tr("Advanced"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/advanced-settings.svg", s), tr("Advanced"), this);
 	DkAdvancedPreference* ap = new DkAdvancedPreference(this);
 	tab->setWidget(ap);
 	pw->addTabWidget(tab);
+
+	// file association preferences
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/manipulation.svg", s), tr("Editor"), this);
+	DkEditorPreference* ep = new DkEditorPreference(this);
+	tab->setWidget(ep);
+	pw->addTabWidget(tab);
+
 	// add preference widget ------------------------------
 
 	return pw;
@@ -519,7 +564,7 @@ DkPreferenceWidget* DkCentralWidget::createPreferences() {
 DkThumbScrollWidget* DkCentralWidget::createThumbScrollWidget() {
 
 	DkThumbScrollWidget* thumbScrollWidget = new DkThumbScrollWidget(this);
-	thumbScrollWidget->getThumbWidget()->setBackgroundBrush(Settings::param().slideShow().backgroundColor);
+	thumbScrollWidget->getThumbWidget()->setBackgroundBrush(DkSettingsManager::param().slideShow().backgroundColor);
 	thumbScrollWidget->registerAction(DkActionManager::instance().action(DkActionManager::menu_panel_thumbview));
 
 	DkActionManager& am = DkActionManager::instance();
@@ -629,11 +674,6 @@ void DkCentralWidget::openPreferences() {
 
 void DkCentralWidget::removeTab(int tabIdx) {
 
-	if (mTabInfos.size() <= 1) {
-		qDebug() << "This tab is the last man standing - I will not destroy it!";
-		return;
-	}
-
 	if (tabIdx == -1)
 		tabIdx = mTabbar->currentIndex();
 
@@ -645,27 +685,25 @@ void DkCentralWidget::removeTab(int tabIdx) {
 			bw->close();
 	}
 
-	for (int idx = 0; idx < mTabInfos.size(); idx++) {
-		
-		if (mTabInfos.at(idx)->getTabIdx() == tabIdx) {
-			mTabInfos.remove(idx);
-			mTabbar->removeTab(tabIdx);
-		}
-	}
-
+	mTabInfos.remove(tabIdx);
+	mTabbar->removeTab(tabIdx);
 	updateTabIdx();
 
+	if (mTabInfos.size() == 0) { // Make sure we have at least one tab
+		addTab();
+		imageUpdatedSignal(mTabInfos.at(0)->getImage());
+		return;
+	}
+
 	if (mTabInfos.size() <= 1)
 		mTabbar->hide();
 }
 
 void DkCentralWidget::clearAllTabs() {
-	
-	// the last tab will never be destroyed (it results in real issues!) - do you need that??
-	for (int idx = 0; idx < mTabInfos.size(); idx++)
-		mTabbar->removeTab(mTabInfos.at(idx)->getTabIdx());
-	
-	//mTabbar->hide();
+
+	int count = getTabs().count();
+	for (int idx = 0; idx < count; idx++)
+		removeTab();
 }
 
 void DkCentralWidget::updateTab(QSharedPointer<DkTabInfo> tabInfo) {
@@ -683,26 +721,30 @@ void DkCentralWidget::updateTabIdx() {
 }
 
 void DkCentralWidget::nextTab() const {
+	int idx = mTabbar->currentIndex();
+	idx++;
+	setActiveTab(idx);
+}
 
+void DkCentralWidget::previousTab() const {
+	int idx = mTabbar->currentIndex();
+	idx--;
+	setActiveTab(idx);
+}
+
+void DkCentralWidget::setActiveTab(int idx) const {
 	if (mTabInfos.size() < 2)
 		return;
 
-	int idx = mTabbar->currentIndex();
-	idx++;
+	if (idx < 0)
+		idx = mTabInfos.size() - 1;
+
 	idx %= mTabInfos.size();
 	mTabbar->setCurrentIndex(idx);
 }
 
-void DkCentralWidget::previousTab() const {
-
-	if (mTabInfos.size() < 2)
-		return;
-
-	int idx = mTabbar->currentIndex();
-	idx--;
-	if (idx < 0)
-		idx = mTabInfos.size()-1;
-	mTabbar->setCurrentIndex(idx);
+int DkCentralWidget::getActiveTab() {
+	return mTabbar->currentIndex();
 }
 
 void DkCentralWidget::imageLoaded(QSharedPointer<DkImageContainerT> img) {
@@ -905,7 +947,7 @@ int DkCentralWidget::currentViewMode() const {
 void DkCentralWidget::restart() const {
 
 	// safe settings first - since the intention of a restart is often a global settings change
-	Settings::param().save();
+	DkSettingsManager::param().save();
 
 	QString exe = QApplication::applicationFilePath();
 	QStringList args;
@@ -966,35 +1008,10 @@ void DkCentralWidget::dragEnterEvent(QDragEnterEvent *event) {
 
 	printf("[DkCentralWidget] drag enter event\n");
 
-	//if (event->source() == this)
-	//	return;
-
-	if (event->mimeData()->hasUrls()) {
-		QUrl url = event->mimeData()->urls().at(0);
-
-		QList<QUrl> urls = event->mimeData()->urls();
-
-		for (int idx = 0; idx < urls.size(); idx++)
-			qDebug() << "url: " << urls.at(idx);
-
-		url = url.toLocalFile();
-
-		// TODO: check if we accept appropriately (network drives that are not mounted)
-		QFileInfo file = QFileInfo(url.toString());
-
-		// just accept image files
-		if (DkUtils::isValid(file))
-			event->acceptProposedAction();
-		else if (file.isDir())
-			event->acceptProposedAction();
-		else if (event->mimeData()->urls().at(0).isValid() && DkUtils::hasValidSuffix(event->mimeData()->urls().at(0).toString()))
-			event->acceptProposedAction();
-
-	}
-	if (event->mimeData()->hasImage()) {
+	if (event->mimeData()->hasUrls() ||
+		event->mimeData()->hasImage()) {
 		event->acceptProposedAction();
 	}
-
 	QWidget::dragEnterEvent(event);
 }
 
@@ -1014,21 +1031,132 @@ void DkCentralWidget::loadDir(const QString& filePath) {
 
 void DkCentralWidget::loadFileToTab(const QString& filePath) {
 
-	if (mTabInfos.size() > 1 || (!mTabInfos.empty() && mTabInfos.at(0)->getMode() != DkTabInfo::tab_empty)) {
-		addTab(filePath);
-	}
-	else
-		mViewport->loadFile(filePath);
+    if (mTabInfos.size() > 1){
+        // this is the first one: open a new tab
+        addTab(filePath);
+    }
+	else {
+        // we already have some opened tabs.
+        int currentTabIdx = mTabbar->currentIndex();
+        enum DkTabInfo::TabMode currentTabMode = mTabInfos[currentTabIdx]->getMode();
+
+        if (currentTabMode == DkTabInfo::tab_thumb_preview ||
+            currentTabMode == DkTabInfo::tab_recent_files ||
+            currentTabMode == DkTabInfo::tab_single_image ||
+            currentTabMode == DkTabInfo::tab_empty) {
+
+			loadFile(filePath);
+            //// reuse the currently open tab.
+            //mTabInfos.at(currentTabIdx)->setFilePath(filePath);
+            //updateTab(mTabInfos.at(currentTabIdx));
+            //currentTabChanged(currentTabIdx);
+
+        }
+		else {
+            // no tab to reuse. open create a new tab
+            addTab(filePath);
+        }
+    }
 }
 
+/**
+ * @brief loadDirToTab loads a directory path into the current tab.
+ * @param dirPath the directory to load
+ */
 void DkCentralWidget::loadDirToTab(const QString& dirPath) {
 
-	if (mTabInfos.size() > 1 || (!mTabInfos.empty() && mTabInfos.at(0)->getMode() != DkTabInfo::tab_empty)) {
-		addTab();
+    if (mTabInfos.size() > 1 ||
+        (!mTabInfos.empty()
+         && mTabInfos.at(0)->getMode() != DkTabInfo::tab_empty
+         && mTabInfos.at(0)->getMode() != DkTabInfo::tab_recent_files
+         && mTabInfos.at(0)->getMode() != DkTabInfo::tab_single_image
+         && mTabInfos.at(0)->getMode() != DkTabInfo::tab_thumb_preview)) {
+
+        addTab();
+    }
+
+    QSharedPointer<DkTabInfo> targetTab = mTabInfos[mTabbar->currentIndex()];
+	QFileInfo di(dirPath);
+
+	if(di.isDir()) {
+		//try to load the dir
+		bool dirIsLoaded = targetTab->setDirPath(dirPath);
+
+        if(dirIsLoaded){
+            //show the directory in overview mode
+            targetTab->setMode(DkTabInfo::tab_thumb_preview);
+            showThumbView();
+            return;
+        }
+    }
+    mViewport->getController()->setInfo(tr("I could not load \"%1\"").arg(dirPath));
+}
+
+/** loadUrl() loads a single valid url
+ *  @param loadInTab: if true, replace the currently active image, so it exists.
+ */
+void DkCentralWidget::loadUrl(const QUrl& url, bool loadInTab) {
+    Q_ASSERT(url.isValid());
+
+    // TODO decide cases where we just load over the current image
+    Q_UNUSED(loadInTab);
+    Q_ASSERT(loadInTab == true);
+
+	// url.toString fixes windows "C:/" vs "C:\"
+    QFileInfo fi(url.toString());
+
+	if (!fi.exists()) {
+		fi = QFileInfo(url.toLocalFile());
 	}
-	
-	mTabInfos.at(mTabbar->currentIndex())->setDirPath(dirPath);
-	showThumbView();
+
+    auto display = [&](QString msg){
+        mViewport->getController()->setInfo(msg.arg(msg));
+    };
+
+    if (fi.exists()) {
+        
+		if (fi.isFile()) {
+            // load a local file
+            if (DkUtils::isValid(fi)) {
+                loadFileToTab(fi.filePath());
+            } 
+			else {
+                display(tr("Unable to load file \"%1\"").arg(fi.canonicalPath()));
+            }
+        } 
+		else if(fi.isDir()) {
+            // load a directory as thmbnail view
+            loadDirToTab(fi.filePath());
+        }
+		else {
+            display(tr("\"%1\" cannot be loaded").arg(fi.canonicalPath()));
+        }
+    }
+	else {
+       //load a remote url
+        QSharedPointer<DkTabInfo> targetTab = mTabInfos[mTabbar->currentIndex()];
+        display(tr("downloading \"%1\"").arg(url.toDisplayString()));
+        targetTab->getImageLoader()->downloadFile(url);
+    }
+}
+
+/** loadUrls() loads a list of valid urls.
+ * @param maxUrlsToLoad determines the maximum
+ */
+void DkCentralWidget::loadUrls(const QList<QUrl>& urls, int maxUrlsToLoad) {
+    
+	if(urls.size() == 0)
+        return;
+
+    if(urls.size() > maxUrlsToLoad){
+        QString urlsWarning(tr("Too many urls to load. Loading only the first %1"));
+        qDebug() << urlsWarning.arg(urls.size());
+    }
+
+    for (int idx = 0; idx < urls.size() && idx < maxUrlsToLoad; idx++) {
+        QUrl url = urls[idx];
+        loadUrl(url);
+    }
 }
 
 void DkCentralWidget::openBatch(const QStringList& selectedFiles) {
@@ -1083,88 +1211,100 @@ void DkCentralWidget::dropEvent(QDropEvent *event) {
 		mViewport->getController()->setInfo(tr("Sorry, I could not drop the content."));
 }
 
+
 bool DkCentralWidget::loadFromMime(const QMimeData* mimeData) {
 
-	if (!mimeData)
-		return false;
+    if (!mimeData)
+        return false;
 
-	if ((mimeData->hasUrls() && mimeData->urls().size() > 0) || mimeData->hasText()) {
-		QUrl url = mimeData->hasText() ? QUrl::fromUserInput(mimeData->text()) : QUrl::fromUserInput(mimeData->urls().at(0).toString());
+    QStringList mimeFmts = mimeData->formats();
+    qDebug() << "loading mime data with formats: " << mimeFmts;
 
-		// try manual conversion first, this fixes the DSC#josef.jpg problems (url fragments)
-		QString fString = url.toString();
-		fString = fString.replace("file:///", "");
+    if (mimeData->hasImage()) {
+        // we got an image buffer
 
-		QFileInfo file = QFileInfo(fString);
-		if (!file.exists()) {	// try an alternative conversion
-			file = QFileInfo(url.toLocalFile());
-			fString = url.toLocalFile();
+        QImage dropImg = qvariant_cast<QImage>(mimeData->imageData());
+        mViewport->loadImage(dropImg);
+        return true;
+    }
+
+    // parse mime data. get a non-empty list of urls. url is the first.
+    QList<QUrl> urls;
+
+	if (mimeFmts.contains("text/uri-list")) {
+		//we got a list of uris
+		//mimeData has both urls and text (empty string. at least for dolphin 16.04.3)
+		for (QUrl u : mimeData->urls()) {
+			if (u.isValid())
+				urls.append(u);
 		}
-		
-		QList<QUrl> urls = mimeData->urls();
-
-		// merge OpenCV vec files if multiple vec files are dropped
-		if (urls.size() > 1 && file.suffix() == "vec") {
-
-			QStringList vecFiles;
-
-			for (int idx = 0; idx < urls.size(); idx++)
-				vecFiles.append(urls.at(idx).toLocalFile());
-
-			// ask user for filename
-			QString sPath(QFileDialog::getSaveFileName(this, tr("Save File"),
-				QFileInfo(vecFiles.first()).absolutePath(), "Cascade Training File (*.vec)"));
-
-			DkBasicLoader loader;
-			int numFiles = loader.mergeVecFiles(vecFiles, sPath);
-
-			if (numFiles) {
-				loadFile(sPath);
-				mViewport->getController()->setInfo(tr("%1 vec files merged").arg(numFiles));
-				return true;
-			}
-
-			return false;
-		}
-		else
-			qDebug() << urls.size() << file.suffix() << " files dropped";
-
-		if (!mTabInfos.empty() && mTabInfos[mTabbar->currentIndex()]->getMode() == DkTabInfo::tab_thumb_preview) {
-			// TODO: this event won't be called if the thumbs view is visible
-
-			// >DIR: TODO [19.2.2015 markus]
-			//QDir newDir = (file.isDir()) ? QDir(file.absoluteFilePath()) : file.absolutePath();
-			//mViewport->getImageLoader()->loadDir(newDir);
-		}
-		else {
-			// just accept image files
-			if (DkUtils::isValid(file) || file.isDir())
-				loadFile(fString);
-			else if (url.isValid() && !mTabInfos.empty()) {
-				mTabInfos[mTabbar->currentIndex()]->getImageLoader()->downloadFile(url);
-			}
-			else
-				return false;
-		}
-
-		for (int idx = 1; idx < urls.size() && idx < 20; idx++) {
-
-			QFileInfo fi = DkUtils::urlToLocalFile(urls[idx]);
-
-			if (DkUtils::isValid(fi))
-				addTab(urls[idx].toLocalFile());
-		}
-
-		return true;
 	}
-	else if (mimeData->hasImage()) {
+    else if(mimeData->formats().contains("text/plain")) {
+        //we got text data. maybe it is a list of urls
+        urls = DkUtils::findUrlsInTextNewline(mimeData->text());
+    }
+    else {
+        //
+        qDebug() << "no handled Mime types found in drop: " << mimeData->formats();
+        return false;
+    }
 
-		QImage dropImg = qvariant_cast<QImage>(mimeData->imageData());
-		mViewport->loadImage(dropImg);
-		return true;
-	}
+    if(urls.size() == 0){
+        return false;
+    }
 
-	return false;
+#ifdef _DEBUG
+    // At this point we have a non empty list of valid urls we can load
+    qDebug() << urls.size() << " files dropped:";
+    for (const QUrl& url: urls) {
+        QString fname = url.toLocalFile();
+        QFileInfo file(fname);
+        qDebug() << QString("url [%1]: %2 %3")
+                        .arg(url.isLocalFile() ? QString("local") : QString("remote"))
+                        .arg(url.toDisplayString())
+                        .arg(url.isLocalFile() ? url.toLocalFile() : QString(""));
+        Q_ASSERT(url.isValid());
+    }
+#endif
+
+    // Pass urls to the appropriate loading function
+    QFileInfo file(urls[0].toLocalFile());
+
+    if (urls.size() > 1 && file.suffix() == "vec") {
+        // assume multiple OpenCV vec files where dropped.
+        return loadCascadeTrainingFiles(urls);
+    } else {
+        // load urls generically
+        loadUrls(urls);
+        return true;
+    }
+    return false;
 }
 
+
+/** load a number of Cascade Trainig files */
+bool DkCentralWidget::loadCascadeTrainingFiles(QList<QUrl> urls) {
+    QStringList vecFiles;
+
+    if (urls.size() > 1 && urls.at(0).toLocalFile().endsWith("vec")) {
+
+        for (int idx = 0; idx < urls.size(); idx++)
+            vecFiles.append(urls.at(idx).toLocalFile());
+
+        // ask user for filename
+        QString sPath(QFileDialog::getSaveFileName(this, tr("Save File"),
+            QFileInfo(vecFiles.first()).absolutePath(), "Cascade Training File (*.vec)"));
+
+        DkBasicLoader loader;
+        int numFiles = loader.mergeVecFiles(vecFiles, sPath);
+
+        if (numFiles) {
+            loadFile(sPath);
+            mViewport->getController()->setInfo(tr("%1 vec files merged").arg(numFiles));
+            return true;
+        }
+    }
+    return false;
 }
+
+} // namespace nmc
