@@ -114,14 +114,14 @@ void DkControlWidget::init() {
 	setMouseTracking(true);
 
 	// connect widgets with their settings
-	mFilePreview->setDisplaySettings(&Settings::param().app().showFilePreview);
-	mMetaDataInfo->setDisplaySettings(&Settings::param().app().showMetaData);
-	mFileInfoLabel->setDisplaySettings(&Settings::param().app().showFileInfoLabel);
-	mPlayer->setDisplaySettings(&Settings::param().app().showPlayer);
-	mHistogram->setDisplaySettings(&Settings::param().app().showHistogram);
-	mCommentWidget->setDisplaySettings(&Settings::param().app().showComment);
-	mZoomWidget->setDisplaySettings(&Settings::param().app().showOverview);
-	mFolderScroll->setDisplaySettings(&Settings::param().app().showScroller);
+	mFilePreview->setDisplaySettings(&DkSettingsManager::param().app().showFilePreview);
+	mMetaDataInfo->setDisplaySettings(&DkSettingsManager::param().app().showMetaData);
+	mFileInfoLabel->setDisplaySettings(&DkSettingsManager::param().app().showFileInfoLabel);
+	mPlayer->setDisplaySettings(&DkSettingsManager::param().app().showPlayer);
+	mHistogram->setDisplaySettings(&DkSettingsManager::param().app().showHistogram);
+	mCommentWidget->setDisplaySettings(&DkSettingsManager::param().app().showComment);
+	mZoomWidget->setDisplaySettings(&DkSettingsManager::param().app().showOverview);
+	mFolderScroll->setDisplaySettings(&DkSettingsManager::param().app().showScroller);
 
 	// some adjustments
 	mBottomLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -320,6 +320,7 @@ void DkControlWidget::connectWidgets() {
 	connect(am.action(DkActionManager::menu_panel_info), SIGNAL(toggled(bool)), this, SLOT(showFileInfo(bool)));
 	connect(am.action(DkActionManager::menu_panel_histogram), SIGNAL(toggled(bool)), this, SLOT(showHistogram(bool)));
 	connect(am.action(DkActionManager::menu_panel_comment), SIGNAL(toggled(bool)), this, SLOT(showCommentWidget(bool)));
+	connect(am.action(DkActionManager::menu_panel_toggle), SIGNAL(toggled(bool)), this, SLOT(toggleHUD(bool)));
 }
 
 void DkControlWidget::update() {
@@ -343,7 +344,11 @@ void DkControlWidget::showWidgetsSettings() {
 		return;
 	}
 
-	//qDebug() << "current app mode: " << Settings::param().app().currentAppMode;
+	// do not show if hide panels is checked
+	if (DkActionManager::instance().action(DkActionManager::menu_panel_toggle)->isChecked())
+		return;
+
+	//qDebug() << "current app mode: " << DkSettingsManager::param().app().currentAppMode;
 
 	showOverview(mZoomWidget->getCurrentDisplaySetting());
 	showPreview(mFilePreview->getCurrentDisplaySetting());
@@ -355,6 +360,14 @@ void DkControlWidget::showWidgetsSettings() {
 	showScroller(mFolderScroll->getCurrentDisplaySetting());
 }
 
+void DkControlWidget::toggleHUD(bool hide) {
+	
+	if (hide)
+		setWidgetsVisible(false, false);
+	else	
+		showWidgetsSettings();
+}
+
 void DkControlWidget::setWidgetsVisible(bool visible, bool saveSettings) {
 
 	mFilePreview->setVisible(visible, saveSettings);
@@ -494,7 +507,7 @@ void DkControlWidget::showCommentWidget(bool visible) {
 
 void DkControlWidget::switchWidget(QWidget* widget) {
 
-	if (mLayout->currentWidget() == widget || !widget && mLayout->currentWidget() == mWidgets[hud_widget])
+	if (mLayout->currentWidget() == widget || (!widget && mLayout->currentWidget() == mWidgets[hud_widget]))
 		return;
 
 	if (widget != mWidgets[hud_widget])
@@ -516,7 +529,7 @@ void DkControlWidget::switchWidget(QWidget* widget) {
 
 }
 
-bool DkControlWidget::closePlugin(bool askForSaving) {
+bool DkControlWidget::closePlugin(bool askForSaving, bool force) {
 #ifdef WITH_PLUGINS
 
 	QSharedPointer<DkPluginContainer> plugin = DkPluginManager::instance().getRunningPlugin();
@@ -531,38 +544,41 @@ bool DkControlWidget::closePlugin(bool askForSaving) {
 
 	// this is that complicated because we do not want plugins to have threaded containers - this could get weird
 	QSharedPointer<DkImageContainerT> pluginImage;
-	
-	if (mViewport->imageContainer()) {
+
+	if (!force) {
 		
-		bool applyChanges = true;
+		if (mViewport->imageContainer()) {
 
-		if (askForSaving) {
+			bool applyChanges = true;
 
-			DkMessageBox* msgBox = new DkMessageBox(
-				QMessageBox::Question, 
-				tr("Closing Plugin"), 
-				tr("Apply plugin changes?"), 
-				QMessageBox::Yes | QMessageBox::No, 
-				this);
-			msgBox->setDefaultButton(QMessageBox::Yes);
-			msgBox->setObjectName("SavePluginChanges");
+			if (askForSaving) {
 
-			int answer = msgBox->exec();
-			applyChanges = (answer == QMessageBox::Accepted || answer == QMessageBox::Yes);
-		}	
+				DkMessageBox* msgBox = new DkMessageBox(
+					QMessageBox::Question,
+					tr("Closing Plugin"),
+					tr("Apply plugin changes?"),
+					QMessageBox::Yes | QMessageBox::No,
+					this);
+				msgBox->setDefaultButton(QMessageBox::Yes);
+				msgBox->setObjectName("SavePluginChanges");
 
-		if (applyChanges)
-			pluginImage = DkImageContainerT::fromImageContainer(vPlugin->runPlugin("", mViewport->imageContainer()));
+				int answer = msgBox->exec();
+				applyChanges = (answer == QMessageBox::Accepted || answer == QMessageBox::Yes);
+			}
+
+			if (applyChanges)
+				pluginImage = DkImageContainerT::fromImageContainer(vPlugin->runPlugin("", mViewport->imageContainer()));
+		}
+		else
+			qDebug() << "[DkControlWidget] I cannot close a plugin if the image container is NULL";
 	}
-	else
-		qDebug() << "[DkControlWidget] I cannot close a plugin if the image container is NULL";
 
 	disconnect(vPlugin->getViewPort(), SIGNAL(showToolbar(QToolBar*, bool)), vPlugin->getMainWindow(), SLOT(showToolbar(QToolBar*, bool)));
 
-	setPluginWidget(vPlugin, true);	// handles deletion
+	setPluginWidget(vPlugin, true);
 	plugin->setActive(false);		// handles states
 
-	if (pluginImage) {
+	if (!force && pluginImage) {
 		mViewport->setEditedImage(pluginImage);
 		return false;
 	}
@@ -595,8 +611,10 @@ void DkControlWidget::setPluginWidget(DkViewPortInterface* pluginWidget, bool re
 
 	mPluginViewport = pluginWidget->getViewPort();
 
-	if (!mPluginViewport) 
+	if (!mPluginViewport) {
+		qDebug() << "cannot set plugin widget since the viewport is NULL" << pluginWidget;
 		return;
+	}
 
 	if (!removeWidget) {
 		mPluginViewport->setWorldMatrix(mViewport->getWorldMatrixPtr());
@@ -606,6 +624,7 @@ void DkControlWidget::setPluginWidget(DkViewPortInterface* pluginWidget, bool re
 		connect(mPluginViewport, SIGNAL(closePlugin(bool)), this, SLOT(closePlugin(bool)), Qt::UniqueConnection);
 		connect(mPluginViewport, SIGNAL(loadFile(const QString&)), mViewport, SLOT(loadFile(const QString&)), Qt::UniqueConnection);
 		connect(mPluginViewport, SIGNAL(loadImage(const QImage&)), mViewport, SLOT(setImage(const QImage&)), Qt::UniqueConnection);
+		connect(mPluginViewport, SIGNAL(showInfo(const QString&)), this, SLOT(setInfo(const QString&)), Qt::UniqueConnection);
 	}
 
 	setAttribute(Qt::WA_TransparentForMouseEvents, !removeWidget && pluginWidget->hideHUD());
@@ -616,11 +635,9 @@ void DkControlWidget::setPluginWidget(DkViewPortInterface* pluginWidget, bool re
 	else if (pluginWidget->hideHUD())
 		showWidgetsSettings();
 
-
 	mViewport->setPaintWidget(dynamic_cast<QWidget*>(mPluginViewport), removeWidget);
-	
+
 	if (removeWidget) {
-		pluginWidget->deleteViewPort();
 		mPluginViewport = 0;
 	}
 }
