@@ -59,9 +59,6 @@
 #include <QAbstractButton>
 #include <QProcess>
 #include <qmath.h>
-#ifdef WITH_UPNP
-#include "DkUpnp.h"
-#endif // WITH_UPNP
 
 #ifdef QT_NO_DEBUG_OUTPUT
 #pragma warning(disable: 4127)		// no 'conditional expression is constant' if qDebug() messages are removed
@@ -81,8 +78,9 @@ DkClientManager::DkClientManager(const QString& title, QObject* parent) : QThrea
 
 DkClientManager::~DkClientManager() {
 	
+	// save settings
 	sendGoodByeToAll();	// does nothing...
-};
+}
 
 
 void DkClientManager::connectionReadyForUse(quint16 peerServerPort, const QString& title, DkConnection* connection) {
@@ -527,15 +525,6 @@ void DkLANClientManager::connectionSynchronized(QList<quint16> synchronizedPeers
 	emit synchronizedPeersListChanged(mPeerList.getSynchronizedPeerServerPorts());
 	emit updateConnectionSignal(mPeerList.getActivePeers());
 
-	// ignore synchronized clients of other connection
-
-	// add to last seen for whitelisting
-	DkPeer* syncedPeer = mPeerList.getPeerById(connection->getPeerId());
-	if (!syncedPeer)
-		return;
-	Settings::param().sync().recentSyncNames << syncedPeer->clientName;
-	Settings::param().sync().recentLastSeen.insert(syncedPeer->clientName, QDateTime::currentDateTime());
-	qDebug() << "added " << syncedPeer->clientName << " to recently seen list";
 }
 
 void DkLANClientManager::connectionStopSynchronized(DkConnection* connection) {
@@ -775,14 +764,6 @@ void DkLANClientManager::startServer(bool flag) {
 		}
 	}
 	server->startServer(flag);
-#ifdef WITH_UPNP
-	qDebug() << "server address:" << server->serverAddress() << " port:" << server->serverPort();
-	if (flag) {
-		emit serverPortChanged(server->serverPort());
-	} else {
-		emit serverPortChanged(0);
-	}
-#endif // WITH_UPNP
 }
 
 
@@ -827,130 +808,6 @@ void DkLANClientManager::connectConnection(DkConnection* connection) {
 	connect(connection, SIGNAL(connectionSwitchServer(DkConnection*, const QHostAddress&, quint16)), this, SLOT(connectionReceivedSwitchServer(DkConnection*, const QHostAddress&, quint16)));
 }
 
-// DkRemoteControllClientManager --------------------------------------------------------------------
-DkRCClientManager::DkRCClientManager(const QString& title, QObject* parent /* = 0 */) : DkLANClientManager(title, parent, rc_udp_port, rc_udp_port) {
-	connect(server, SIGNAL(sendStopSynchronizationToAll()), this, SLOT(sendStopSynchronizationToAll()));
-}
-
-QList<DkPeer*> DkRCClientManager::getPeerList() {
-	QList<DkPeer*> list;
-	foreach(DkPeer* peer, mPeerList.getPeerList()) {
-		
-		if (peer && permissionList.value(peer->peerId) && peer->connection->connectionCreated)
-			list.push_back(peer);
-	}
-	return list;
-}
-
-void DkRCClientManager::synchronizeWith(quint16 peerId) {
-	//qDebug() << "DkCRemoteControllientManager::synchronizeWith  peerId:" << peerId;
-
-	mPeerList.setSynchronized(peerId, true); // will be reset if other client does not response within 1 sec
-
-	qDebug() << "DkRCClientManager: peer list:" << __FILE__ << __FUNCTION__;
-	qDebug() << "--------- peerList -------";
-	mPeerList.print();
-	qDebug() << "--------- peerList end----";
-
-	DkPeer* peer = mPeerList.getPeerById(peerId);
-	if (!peer || peer->connection == 0) {
-		qDebug() << "TcpClient: synchronizeWith: connection is null";
-		return;
-	}
-
-	//qDebug() << "synchronizing with: " << peerId;
-	connect(this,SIGNAL(sendSynchronizeMessage()), peer->connection, SLOT(sendStartSynchronizeMessage()));
-	emit sendSynchronizeMessage();
-	disconnect(this,SIGNAL(sendSynchronizeMessage()), peer->connection, SLOT(sendStartSynchronizeMessage()));
-
-	emit synchronizedPeersListChanged(mPeerList.getSynchronizedPeerServerPorts());
-}
-
-void DkRCClientManager::connectionSynchronized(QList<quint16> synchronizedPeersOfOtherClient, DkConnection* connection) {
-	DkPeer* peer = mPeerList.getPeerById(connection->getPeerId());
-	if (!peer)
-		return;
-
-	//qDebug() << "Connection synchronized with:" << connection->getPeerPort();
-	mPeerList.setSynchronized(connection->getPeerId(), true);
-	mPeerList.setShowInMenu(connection->getPeerId(), true);
-	emit synchronizedPeersListChanged(mPeerList.getSynchronizedPeerServerPorts());
-	emit updateConnectionSignal(mPeerList.getActivePeers());
-
-	// ignore synchronized clients of other connection
-
-	// add to last seen for whitelisting
-	Settings::param().sync().recentSyncNames << peer->clientName;
-	Settings::param().sync().recentLastSeen.insert(peer->clientName, QDateTime::currentDateTime());
-
-}
-
-
-
-void DkRCClientManager::connectionReadyForUse(quint16 peerServerPort, const QString& title, DkConnection* dkconnection) {
-	//DkLANClientManager::connectionReadyForUse(peerServerPort, title, dkconnection);
-	//peerList.print();
-	//DkPeer peer = peerList.getPeerByAddress(dkconnection->peerAddress(), peerServerPort);
-	//permissionList.insert(peer.peerId, false);
-
-	DkRCConnection* connection = dynamic_cast<DkRCConnection*>(dkconnection); // TODO???? darf ich das
-	//qDebug() << "connection ready for use" << connection->peerPort() << " with title:" << title << " peerServerPort:" << peerServerPort << "  showInMenu: " << connection->getShowInMenu();
-
-	mNewPeerId++;
-	DkPeer* peer = new DkPeer(connection->peerPort(), mNewPeerId, connection->peerAddress(), peerServerPort, title, connection, false, connection->getClientName(), connection->getShowInMenu(), this);
-	connection->setPeerId(mNewPeerId);
-	mPeerList.addPeer(peer); 
-
-	//qDebug() << "peerList:";
-	//peerList.print();
-
-	//if (!server->isListening())
-		connection->sendAskForPermission(); // TODO: do i have to ask for permission?
-}
-
-void DkRCClientManager::connectionReceivedPermission(DkConnection* connection, bool allowedToConnect) {
-	permissionList.insert(connection->getPeerId(), allowedToConnect);
-}
-
-void DkRCClientManager::connectionReceivedRCType(DkConnection*, int mode) {
-	qDebug() << "connection received new remote control mode: " << mode;
-	emit(connectedReceivedNewMode(mode));
-}
-
-void DkRCClientManager::connectionReceivedGoodBye(DkConnection* connection) {
-	emit connectedReceivedNewMode(DkSettings::sync_mode_default);
-	DkClientManager::connectionReceivedGoodBye(connection);
-}
-
-DkRCConnection* DkRCClientManager::createConnection() {
-	DkRCConnection* connection = new DkRCConnection();
-	connectConnection(connection);
-	return connection;
-}
-
-void DkRCClientManager::connectConnection(DkConnection* connection) {
-	DkLANClientManager::connectConnection(connection);
-	connect(connection, SIGNAL(connectionNewPermission(DkConnection*, bool)), this, SLOT(connectionReceivedPermission(DkConnection*, bool)));
-	connect(connection, SIGNAL(connectionNewRCType(DkConnection*, int)), this, SLOT(connectionReceivedRCType(DkConnection*, int)));
-}
-
-void DkRCClientManager::sendNewMode(int mode) {
-	
-	//qDebug() << "sending new image";
-	QList<DkPeer*> synchronizedPeers = mPeerList.getSynchronizedPeers();
-	foreach (DkPeer* peer , synchronizedPeers) {
-		
-		if (!peer)
-			continue;
-		
-		DkRCConnection* connection = dynamic_cast<DkRCConnection*>(peer->connection);
-		connect(this,SIGNAL(sendNewModeMessage(int)), connection, SLOT(sendRCType(int)));
-		emit sendNewModeMessage(mode);
-		disconnect(this,SIGNAL(sendNewModeMessage(int)), connection, SLOT(sendRCType(int)));
-	}
-}
-
-
 // DkLocalTcpServer --------------------------------------------------------------------
 DkLocalTcpServer::DkLocalTcpServer(QObject* parent) : QTcpServer(parent) {
 	
@@ -1186,7 +1043,7 @@ void DkPeer::setSynchronized(bool flag) {
 	hasChangedRecently = true;
 	connect(timer, SIGNAL(timeout()), this, SLOT(timerTimeout()), Qt::UniqueConnection);
 	timer->start(4000);
-};
+}
 
 bool DkPeer::operator==(const DkPeer& peer) const {
 
@@ -1454,17 +1311,6 @@ void DkLanManagerThread::connectClient() {
 	connect(this, SIGNAL(startServerSignal(bool)), clientManager, SLOT(startServer(bool)));
 	connect(this, SIGNAL(goodByeToAllSignal()), clientManager, SLOT(sendGoodByeToAll()));
 
-	// TODO: uncomment OR do a better signaling here...
-	//connect(clientManager, SIGNAL(sendInfoSignal(const QString&, int)), parent->viewport()->getController(), SLOT(setInfo(const QString&, int)));
-
-#ifdef WITH_UPNP
-	qRegisterMetaType<QHostAddress>("QHostAddress");
-	connect(upnpControlPoint.data(), SIGNAL(newLANNomacsFound(const QHostAddress&, quint16, const QString&)), clientManager, SLOT(startConnection(const QHostAddress&, quint16, const QString&)), Qt::QueuedConnection);
-	connect(clientManager, SIGNAL(serverPortChanged(quint16)), upnpDeviceHost.data(), SLOT(tcpServerPortChanged(quint16)), Qt::QueuedConnection);
-	
-#endif // WITH_UPNP
-
-
 	DkManagerThread::connectClient();
 }
 
@@ -1476,45 +1322,4 @@ void DkLanManagerThread::createClient(const QString& title) {
 	clientManager = new DkLANClientManager(title);
 }
 
-// DkRCManagerThread --------------------------------------------------------------------
-DkRCManagerThread::DkRCManagerThread(DkNoMacs* parent) : DkLanManagerThread(parent) {
-	clientManager = 0;
-}
-
-void DkRCManagerThread::createClient(const QString& title) {
-	if (clientManager)
-		delete clientManager;
-
-	clientManager = new DkRCClientManager(title);
-
-}
-
-void DkRCManagerThread::connectClient() {
-	// not sure if we need something here
-
-	//connect(parent->mViewport(), SIGNAL(sendImageSignal(QImage, const QString&)), clientManager, SLOT(sendNewImage(QImage, const QString&)));
-	//connect(clientManager, SIGNAL(receivedImage(const QImage&)), parent->mViewport(), SLOT(loadImage(const QImage&)));
-	//connect(clientManager, SIGNAL(sendInfoSignal(const QString&, int)), parent->mViewport()->getController(), SLOT(setInfo(const QString&, int)));
-	//connect(clientManager, SIGNAL(receivedImageTitle(const QString&)), parent, SLOT(setWindowTitle(const QString&)));
-	//connect(this, SIGNAL(startServerSignal(bool)), clientManager, SLOT(startServer(bool)));
-	connect(this, SIGNAL(newModeSignal(int)), clientManager, SLOT(sendNewMode(int)));
-	connect(parent, SIGNAL(stopSynchronizeWithSignal()), clientManager, SLOT(stopSynchronizeWith()));
-	connect(clientManager, SIGNAL(connectedReceivedNewMode(int)), parent, SLOT(tcpChangeSyncMode(int)));
-
-	DkLanManagerThread::connectClient();
-
-#ifdef WITH_UPNP
-	 //disconnect signals made by lan manager thread
-	disconnect(upnpControlPoint.data(), SIGNAL(newLANNomacsFound(const QHostAddress&, quint16, const QString&)), clientManager, SLOT(startConnection(const QHostAddress&, quint16, const QString&)));
-	disconnect(clientManager, SIGNAL(serverPortChanged(quint16)), upnpDeviceHost.data(), SLOT(tcpServerPortChanged(quint16)));
-	connect(upnpControlPoint.data(), SIGNAL(newRCNomacsFound(const QHostAddress&, quint16, const QString&)), clientManager, SLOT(startConnection(const QHostAddress&, quint16, const QString&)), Qt::QueuedConnection);
-	connect(clientManager, SIGNAL(serverPortChanged(quint16)), upnpDeviceHost.data(), SLOT(wlServerPortChanged(quint16)), Qt::QueuedConnection);
-#endif // WITH_UPNP
-
-}
-
-void DkRCManagerThread::sendNewMode(int mode) {
-	newModeSignal(mode);
-}
-
 }
