@@ -82,8 +82,8 @@ void DkFilePreview::init() {
 	
 	//thumbsLoader = 0;
 
-	xOffset = qRound(Settings::param().display().thumbSize*0.1f);
-	yOffset = qRound(Settings::param().display().thumbSize*0.1f);
+	xOffset = qRound(DkSettingsManager::param().effectiveThumbSize(this)*0.1f);
+	yOffset = qRound(DkSettingsManager::param().effectiveThumbSize(this)*0.1f);
 
 	currentDx = 0;
 	currentFileIdx = -1;
@@ -109,7 +109,7 @@ void DkFilePreview::init() {
 	rightGradient.setColorAt(1, Qt::black);
 	rightGradient.setColorAt(0, Qt::white);
 
-	minHeight = Settings::param().display().thumbSize + yOffset;
+	minHeight = DkSettingsManager::param().effectiveThumbSize(this) + yOffset;
 	//resize(parent->width(), minHeight);
 	
 	selected = -1;
@@ -132,7 +132,7 @@ void DkFilePreview::initOrientations() {
 	if (windowPosition == pos_dock_ver || windowPosition == pos_dock_hor)
 		minHeight = max_thumb_size;
 	else
-		minHeight = Settings::param().display().thumbSize;
+		minHeight = DkSettingsManager::param().effectiveThumbSize(this);
 
 	if (orientation == Qt::Horizontal) {
 
@@ -169,7 +169,7 @@ void DkFilePreview::initOrientations() {
 
 void DkFilePreview::loadSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup(objectName());
 	windowPosition = settings.value("windowPosition", windowPosition).toInt();
 	settings.endGroup();
@@ -178,7 +178,7 @@ void DkFilePreview::loadSettings() {
 
 void DkFilePreview::saveSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup(objectName());
 	settings.setValue("windowPosition", windowPosition);
 	settings.endGroup();
@@ -219,12 +219,12 @@ void DkFilePreview::paintEvent(QPaintEvent*) {
 	//if (selected != -1)
 	//	resize(parent->width(), minHeight+fileLabel->height());	// catch parent resize...
 
-	if (minHeight != Settings::param().display().thumbSize + yOffset && windowPosition != pos_dock_hor && windowPosition != pos_dock_ver) {
+	if (minHeight != DkSettingsManager::param().effectiveThumbSize(this) + yOffset && windowPosition != pos_dock_hor && windowPosition != pos_dock_ver) {
 
-		xOffset = qCeil(Settings::param().display().thumbSize*0.1f);
-		yOffset = qCeil(Settings::param().display().thumbSize*0.1f);
+		xOffset = qCeil(DkSettingsManager::param().effectiveThumbSize(this)*0.1f);
+		yOffset = qCeil(DkSettingsManager::param().effectiveThumbSize(this)*0.1f);
 
-		minHeight = Settings::param().display().thumbSize + yOffset;
+		minHeight = DkSettingsManager::param().effectiveThumbSize(this) + yOffset;
 		
 		if (orientation == Qt::Horizontal)
 			setMaximumSize(QWIDGETSIZE_MAX, minHeight);
@@ -290,7 +290,7 @@ void DkFilePreview::drawThumbs(QPainter* painter) {
 		
 		// if the image is loaded draw that (it might be edited)
 		if (mThumbs.at(idx)->hasImage()) {
-			img = mThumbs.at(idx)->imageScaledToHeight(Settings::param().display().thumbSize);
+			img = mThumbs.at(idx)->imageScaledToHeight(DkSettingsManager::param().effectiveThumbSize(this));
 		}
 		else {
 
@@ -303,11 +303,11 @@ void DkFilePreview::drawThumbs(QPainter* painter) {
 				img = thumb->getImage();
 		}
 
-		if (img.width() > 160)
+		if (img.width() > max_thumb_size * DkSettingsManager::param().dpiScaleFactor())
 			qDebug() << thumb->getFilePath() << "size:" << img.size();
 
 		QPointF anchor = orientation == Qt::Horizontal ? bufferDim.topRight() : bufferDim.bottomLeft();
-		QRectF r = !img.isNull() ? QRectF(anchor, img.size()) : QRectF(anchor, QSize(Settings::param().display().thumbSize, Settings::param().display().thumbSize));
+		QRectF r = !img.isNull() ? QRectF(anchor, img.size()) : QRectF(anchor, QSize(DkSettingsManager::param().effectiveThumbSize(this), DkSettingsManager::param().effectiveThumbSize(this)));
 		if (orientation == Qt::Horizontal && height()-yOffset < r.height()*2)
 			r.setSize(QSizeF(qFloor(r.width()*(float)(height()-yOffset)/r.height()), height()-yOffset));
 		else if (orientation == Qt::Vertical && width()-yOffset < r.width()*2)
@@ -337,23 +337,30 @@ void DkFilePreview::drawThumbs(QPainter* painter) {
 			newFileRect = imgWorldRect;
 
 		// is the current image within the canvas?
-		if (orientation == Qt::Horizontal && imgWorldRect.right() < 0 || orientation == Qt::Vertical && imgWorldRect.bottom() < 0)
+		if ((orientation == Qt::Horizontal && imgWorldRect.right() < 0) ||
+			(orientation == Qt::Vertical && imgWorldRect.bottom() < 0)) {
 			continue;
-		if ((orientation == Qt::Horizontal && imgWorldRect.left() > width() || orientation == Qt::Vertical && imgWorldRect.top() > height()) && scrollToCurrentImage) 
+		}
+
+		if (((orientation == Qt::Horizontal && imgWorldRect.left() > width()) ||
+			(orientation == Qt::Vertical && imgWorldRect.top() > height())) && scrollToCurrentImage) {
 			continue;
-		else if (orientation == Qt::Horizontal && imgWorldRect.left() > width() || orientation == Qt::Vertical && imgWorldRect.top() > height())
+		}
+		else if ((orientation == Qt::Horizontal && imgWorldRect.left() > width()) ||
+			(orientation == Qt::Vertical && imgWorldRect.top() > height())) {
 			break;
+		}
 
 		if (thumb->hasImage() == DkThumbNail::not_loaded && 
-			Settings::param().resources().numThumbsLoading < Settings::param().resources().maxThumbsLoading) {
+			DkSettingsManager::param().resources().numThumbsLoading < DkSettingsManager::param().resources().maxThumbsLoading) {
 				thumb->fetchThumb();
 				connect(thumb.data(), SIGNAL(thumbLoadedSignal()), this, SLOT(update()));
 		}
 
 		bool isLeftGradient = (orientation == Qt::Horizontal && worldMatrix.dx() < 0 && imgWorldRect.left() < leftGradient.finalStop().x()) ||
 			(orientation == Qt::Vertical && worldMatrix.dy() < 0 && imgWorldRect.top() < leftGradient.finalStop().y());
-		bool isRightGradient = orientation == Qt::Horizontal && imgWorldRect.right() > rightGradient.start().x() ||
-			orientation == Qt::Vertical && imgWorldRect.bottom() > rightGradient.start().y();
+		bool isRightGradient = (orientation == Qt::Horizontal && imgWorldRect.right() > rightGradient.start().x()) ||
+			(orientation == Qt::Vertical && imgWorldRect.bottom() > rightGradient.start().y());
 		// show that there are more images...
 		if (isLeftGradient && !img.isNull())
 			drawFadeOut(leftGradient, imgWorldRect, &img);
@@ -380,7 +387,7 @@ void DkFilePreview::drawNoImgEffect(QPainter* painter, const QRectF& r) {
 	QBrush oldBrush = painter->brush();
 	QPen oldPen = painter->pen();
 
-	QPen noImgPen(Settings::param().display().bgColor);
+	QPen noImgPen(DkSettingsManager::param().display().bgColor);
 	painter->setPen(noImgPen);
 	painter->setBrush(QColor(0,0,0,0));
 	painter->drawRect(r);
@@ -395,7 +402,7 @@ void DkFilePreview::drawSelectedEffect(QPainter* painter, const QRectF& r) {
 	
 	// drawing
 	painter->setOpacity(0.4);
-	painter->setBrush(Settings::param().display().highlightColor);
+	painter->setBrush(DkSettingsManager::param().display().highlightColor);
 	painter->drawRect(r);
 	
 	// reset painter
@@ -414,7 +421,7 @@ void DkFilePreview::drawCurrentImgEffect(QPainter* painter, const QRectF& r) {
 	cr.setSize(QSize((int)cr.width()+1, (int)cr.height()+1));
 	cr.moveCenter(cr.center() + QPointF(-1,-1));
 
-	QPen cPen(Settings::param().display().highlightColor, 1);
+	QPen cPen(DkSettingsManager::param().display().highlightColor, 1);
 	painter->setBrush(QColor(0,0,0,0));
 	painter->setOpacity(1.0);
 	painter->setPen(cPen);
@@ -470,8 +477,8 @@ void DkFilePreview::resizeEvent(QResizeEvent *event) {
 	QWidget* pw = qobject_cast<QWidget*>(parent());
 
 	if (event->size() == event->oldSize() && 
-		(orientation == Qt::Horizontal && pw && this->width() == pw->width()  ||
-		orientation == Qt::Vertical && pw && this->height() == pw->height())) {
+		((orientation == Qt::Horizontal && pw && this->width() == pw->width())  ||
+		(orientation == Qt::Vertical && pw && this->height() == pw->height()))) {
 	
 			qDebug() << "parent size: " << pw->height();
 			return;
@@ -545,7 +552,7 @@ void DkFilePreview::mouseMoveEvent(QMouseEvent *event) {
 	bool left = pdx < ndx;
 	float dx = (left) ? (float)pdx : (float)ndx;
 
-	if (dx < borderTrigger && (mouseDir < 0 && left || mouseDir > 0 && !left)) {
+	if (dx < borderTrigger && ((mouseDir < 0 && left) || (mouseDir > 0 && !left))) {
 		dx = std::exp((borderTrigger - dx)/borderTrigger*3);
 		currentDx = (left) ? dx : -dx;
 
@@ -569,7 +576,7 @@ void DkFilePreview::mouseMoveEvent(QMouseEvent *event) {
 
 				if (selected <= mThumbs.size() && selected >= 0) {
 					QSharedPointer<DkThumbNailT> thumb = mThumbs.at(selected)->getThumb();
-					//selectedImg = DkImage::colorizePixmap(QPixmap::fromImage(thumb->getImage()), Settings::param().display().highlightColor, 0.3f);
+					//selectedImg = DkImage::colorizePixmap(QPixmap::fromImage(thumb->getImage()), DkSettingsManager::param().display().highlightColor, 0.3f);
 
 					// important: setText shows the label - if you then hide it here again you'll get a stack overflow
 					//if (fileLabel->height() < height())
@@ -650,7 +657,7 @@ void DkFilePreview::wheelEvent(QWheelEvent *event) {
 
 	if (event->modifiers() == Qt::CTRL && windowPosition != pos_dock_hor && windowPosition != pos_dock_ver) {
 
-		int newSize = Settings::param().display().thumbSize;
+		int newSize = DkSettingsManager::param().display().thumbSize;
 		newSize += qRound(event->delta()*0.05f);
 
 		// make sure it is even
@@ -659,11 +666,11 @@ void DkFilePreview::wheelEvent(QWheelEvent *event) {
 
 		if (newSize < 8)
 			newSize = 8;
-		else if (newSize > 160)
-			newSize = 160;
+		else if (newSize > max_thumb_size)
+			newSize = max_thumb_size;
 
-		if (newSize != Settings::param().display().thumbSize) {
-			Settings::param().display().thumbSize = newSize;
+		if (newSize != DkSettingsManager::param().display().thumbSize) {
+			DkSettingsManager::param().display().thumbSize = newSize;
 			update();
 		}
 	}
@@ -671,7 +678,7 @@ void DkFilePreview::wheelEvent(QWheelEvent *event) {
 		
 		int fc = (event->delta() > 0) ? -1 : 1;
 		
-		if (!Settings::param().resources().waitForLastImg) {
+		if (!DkSettingsManager::param().resources().waitForLastImg) {
 			currentFileIdx += fc;
 			scrollToCurrentImage = true;
 		}
@@ -730,7 +737,7 @@ void DkFilePreview::newPosition() {
 	}
 
 	// don't apply twice
-	if (windowPosition == pos || pos == pos_dock_hor && windowPosition == pos_dock_ver)
+	if (windowPosition == pos || (pos == pos_dock_hor && windowPosition == pos_dock_ver))
 		return;
 
 	windowPosition = pos;
@@ -781,7 +788,7 @@ void DkFilePreview::moveImages() {
 	float bufferPos		= orientation == Qt::Horizontal ? (float)bufferDim.right() : (float)bufferDim.bottom();
 
 	// do not scroll out of the thumbs
-	if (translation >= limit*0.5 && currentDx > 0 || translation <= -(bufferPos-limit*0.5+xOffset) && currentDx < 0)
+	if ((translation >= limit*0.5 && currentDx > 0) || (translation <= -(bufferPos-limit*0.5+xOffset) && currentDx < 0))
 		return;
 
 	// set the last step to match the center of the screen...	(nicer if user scrolls very fast)
@@ -907,10 +914,10 @@ void DkThumbLabel::setThumb(QSharedPointer<DkThumbNailT> thumb) {
 	mNoImagePen.setColor(QColor(150,150,150));
 	mNoImageBrush = QColor(100,100,100,50);
 
-	QColor col = Settings::param().display().highlightColor;
+	QColor col = DkSettingsManager::param().display().highlightColor;
 	col.setAlpha(90);
 	mSelectBrush = col;
-	mSelectPen.setColor(Settings::param().display().highlightColor);
+	mSelectPen.setColor(DkSettingsManager::param().display().highlightColor);
 	//selectPen.setWidth(2);
 }
 
@@ -921,7 +928,8 @@ QPixmap DkThumbLabel::pixmap() const {
 
 QRectF DkThumbLabel::boundingRect() const {
 
-	return QRectF(QPoint(0,0), QSize(Settings::param().display().thumbPreviewSize, Settings::param().display().thumbPreviewSize));
+    int sz = DkSettingsManager::param().effectiveThumbPreviewSize();
+	return QRectF(QPoint(0,0), QSize(sz, sz));
 }
 
 QPainterPath DkThumbLabel::shape() const {
@@ -943,7 +951,7 @@ void DkThumbLabel::updateLabel() {
 
 		pm = QPixmap::fromImage(mThumb->getImage());
 
-		if (Settings::param().display().displaySquaredThumbs) {
+		if (DkSettingsManager::param().display().displaySquaredThumbs) {
 
 			pm = DkImage::makeSquare(pm);
 		}
@@ -966,7 +974,7 @@ void DkThumbLabel::updateLabel() {
 	//text.setTextWidth(icon.boundingRect().width());
 	QFont font;
 	font.setBold(false);
-	font.setPixelSize(10);
+	font.setPointSize(8);
 	mText.setFont(font);
 	mText.setPlainText(QFileInfo(mThumb->getFilePath()).fileName());
 	mText.hide();
@@ -984,7 +992,7 @@ void DkThumbLabel::updateSize() {
 
 	// resize pixmap label
 	int maxSize = qMax(mIcon.pixmap().width(), mIcon.pixmap().height());
-	int ps = Settings::param().display().thumbPreviewSize;
+	int ps = DkSettingsManager::param().effectiveThumbPreviewSize();
 
 	if ((float)ps/maxSize != mIcon.scale()) {
 		mIcon.setScale(1.0f);
@@ -1041,7 +1049,7 @@ void DkThumbLabel::setVisible(bool visible) {
 void DkThumbLabel::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget) {
 	
 	if (!mFetchingThumb && mThumb->hasImage() == DkThumbNail::not_loaded && 
-		Settings::param().resources().numThumbsLoading < Settings::param().resources().maxThumbsLoading*2) {
+		DkSettingsManager::param().resources().numThumbsLoading < DkSettingsManager::param().resources().maxThumbsLoading*2) {
 			mThumb->fetchThumb();
 			mFetchingThumb = true;
 	}
@@ -1061,7 +1069,7 @@ void DkThumbLabel::paint(QPainter* painter, const QStyleOptionGraphicsItem* opti
 		painter->drawRect(boundingRect());
 	}
 	else if (mIcon.pixmap().isNull()) {
-		QColor c = Settings::param().display().highlightColor;
+		QColor c = DkSettingsManager::param().display().highlightColor;
 		c.setAlpha(30);
 		painter->setPen(mNoImagePen);
 		painter->setBrush(c);
@@ -1091,7 +1099,7 @@ void DkThumbLabel::paint(QPainter* painter, const QStyleOptionGraphicsItem* opti
 	painter->setTransform(mt);
 
 	// draw text
-	if (boundingRect().width() > 50 && Settings::param().display().showThumbLabel) {
+	if (boundingRect().width() > 50 && DkSettingsManager::param().display().showThumbLabel) {
 		
 		QTransform tt = mt;
 		tt.translate(0, boundingRect().height()-mText.boundingRect().height());
@@ -1100,7 +1108,7 @@ void DkThumbLabel::paint(QPainter* painter, const QStyleOptionGraphicsItem* opti
 		r.setWidth(boundingRect().width());
 		painter->setPen(Qt::NoPen);
 		painter->setWorldTransform(tt);
-		painter->setBrush(Settings::param().display().hudBgColor);
+		painter->setBrush(DkSettingsManager::param().display().hudBgColor);
 		painter->drawRect(r);
 		mText.paint(painter, &noSelOption, widget);
 		painter->setWorldTransform(mt);
@@ -1140,12 +1148,13 @@ void DkThumbScene::updateLayout() {
 	if (!views().empty())
 		pSize = QSize(views().first()->viewport()->size());
 
-	mXOffset = qCeil(Settings::param().display().thumbPreviewSize*0.1f);
-	mNumCols = qMax(qFloor(((float)pSize.width()-mXOffset)/(Settings::param().display().thumbPreviewSize + mXOffset)), 1);
+    int psz = DkSettingsManager::param().effectiveThumbPreviewSize();
+	mXOffset = qCeil(psz*0.1f);
+	mNumCols = qMax(qFloor(((float)pSize.width()-mXOffset)/(psz + mXOffset)), 1);
 	mNumCols = qMin(mThumbLabels.size(), mNumCols);
 	mNumRows = qCeil((float)mThumbLabels.size()/mNumCols);
 
-	int tso = Settings::param().display().thumbPreviewSize+mXOffset;
+	int tso = psz+mXOffset;
 	setSceneRect(0, 0, mNumCols*tso+mXOffset, mNumRows*tso+mXOffset);
 	//int fileIdx = thumbPool->getCurrentFileIdx();
 
@@ -1167,11 +1176,11 @@ void DkThumbScene::updateLayout() {
 			cLabel->setPos(cXOffset, cYOffset);
 			cLabel->updateSize();
 
-			cXOffset += Settings::param().display().thumbPreviewSize + mXOffset;
+			cXOffset += psz + mXOffset;
 		}
 
 		// update ypos
-		cYOffset += Settings::param().display().thumbPreviewSize + mXOffset;	// 20 for label 
+		cYOffset += psz + mXOffset;	// 20 for label 
 	}
 
 	for (int idx = 0; idx < mThumbLabels.size(); idx++) {
@@ -1244,12 +1253,17 @@ void DkThumbScene::connectLoader(QSharedPointer<DkImageLoader> loader, bool conn
 
 void DkThumbScene::showFile(const QString& filePath) {
 
-	if (filePath == QDir::currentPath() || filePath.isEmpty())
-		DkStatusBarManager::instance().setMessage(tr("").arg(QString::number(mThumbLabels.size())));
+	if (filePath == QDir::currentPath() || filePath.isEmpty()) {
+		int sf = getSelectedFiles().size();
+
+		if (sf > 1)
+			DkStatusBarManager::instance().setMessage(tr("%1 selected").arg(QString::number(sf)));
+		else
+			DkStatusBarManager::instance().setMessage(tr("%1 images").arg(QString::number(mThumbLabels.size())));
+	}
 	else
 		DkStatusBarManager::instance().setMessage(QFileInfo(filePath).fileName());
 
-	DkStatusBarManager::instance().setMessage(tr("%1 Images").arg(QString::number(mThumbLabels.size())), DkStatusBar::status_filenumber_info);
 }
 
 void DkThumbScene::ensureVisible(QSharedPointer<DkImageContainerT> img) const {
@@ -1269,25 +1283,25 @@ void DkThumbScene::ensureVisible(QSharedPointer<DkImageContainerT> img) const {
 
 void DkThumbScene::toggleThumbLabels(bool show) {
 
-	Settings::param().display().showThumbLabel = show;
+	DkSettingsManager::param().display().showThumbLabel = show;
 
 	for (int idx = 0; idx < mThumbLabels.size(); idx++)
 		mThumbLabels.at(idx)->updateLabel();
 
 	//// well, that's not too beautiful
-	//if (Settings::param().display().displaySquaredThumbs)
+	//if (DkSettingsManager::param().display().displaySquaredThumbs)
 	//	updateLayout();
 }
 
 void DkThumbScene::toggleSquaredThumbs(bool squares) {
 
-	Settings::param().display().displaySquaredThumbs = squares;
+	DkSettingsManager::param().display().displaySquaredThumbs = squares;
 
 	for (int idx = 0; idx < mThumbLabels.size(); idx++)
 		mThumbLabels.at(idx)->updateLabel();
 
 	// well, that's not too beautiful
-	if (Settings::param().display().displaySquaredThumbs)
+	if (DkSettingsManager::param().display().displaySquaredThumbs)
 		updateLayout();
 }
 
@@ -1306,12 +1320,12 @@ void DkThumbScene::resizeThumbs(float dx) {
 	if (dx < 0)
 		dx += 2.0f;
 
-	int newSize = qRound(Settings::param().display().thumbPreviewSize * dx);
+	int newSize = qRound(DkSettingsManager::param().display().thumbPreviewSize * dx);
 	qDebug() << "delta: " << dx;
 	qDebug() << "newsize: " << newSize;
 
-	if (newSize > 6 && newSize <= 160) {
-		Settings::param().display().thumbPreviewSize = newSize;
+	if (newSize > 6 && newSize <= max_thumb_size) {
+		DkSettingsManager::param().display().thumbPreviewSize = newSize;
 		updateLayout();
 	}
 }
@@ -1346,6 +1360,7 @@ void DkThumbScene::selectThumbs(bool selected /* = true */, int from /* = 0 */,
 	}
 	blockSignals(false);
 	emit selectionChanged();
+	showFile();	// update selection label
 }
 
 void DkThumbScene::copySelected() const {
@@ -1796,10 +1811,10 @@ void DkThumbsView::dropEvent(QDropEvent *event) {
 
 void DkThumbsView::fetchThumbs() {
 
-	int maxThreads = Settings::param().resources().maxThumbsLoading*2;
+	int maxThreads = DkSettingsManager::param().resources().maxThumbsLoading*2;
 
 	// don't do anything if it is loading anyway
-	if (Settings::param().resources().numThumbsLoading/* > maxThreads*/) {
+	if (DkSettingsManager::param().resources().numThumbsLoading/* > maxThreads*/) {
 		return;
 	}
 
@@ -1855,11 +1870,11 @@ DkThumbScrollWidget::DkThumbScrollWidget(QWidget* parent /* = 0 */, Qt::WindowFl
 void DkThumbScrollWidget::createToolbar() {
 
 	mToolbar = new QToolBar(tr("Thumb Preview Toolbar"), this);
-	mToolbar->setIconSize(QSize(Settings::param().display().iconSize, Settings::param().display().iconSize));
+	mToolbar->setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
 
 	qDebug() << mToolbar->styleSheet();
 
-	if (Settings::param().display().toolbarGradient) {
+	if (DkSettingsManager::param().display().toolbarGradient) {
 		mToolbar->setObjectName("toolBarWithGradient");
 	}
 
@@ -1886,10 +1901,10 @@ void DkThumbScrollWidget::createToolbar() {
 	toolButton->setMenu(m);
 	toolButton->setAccessibleName(menuTitle);
 	toolButton->setText(menuTitle);
-	QPixmap pm = QIcon(":/nomacs/img/sort.svg").pixmap(Settings::param().display().iconSize);
+	QPixmap pm = QIcon(":/nomacs/img/sort.svg").pixmap(DkSettingsManager::param().effectiveIconSize(this));
 
-	if (!Settings::param().display().defaultIconColor || Settings::param().app().privateMode)
-		pm = DkImage::colorizePixmap(pm, Settings::param().display().iconColor);
+	if (!DkSettingsManager::param().display().defaultIconColor || DkSettingsManager::param().app().privateMode)
+		pm = DkImage::colorizePixmap(pm, DkSettingsManager::param().display().iconColor);
 
 	toolButton->setIcon(pm);
 	toolButton->setPopupMode(QToolButton::InstantPopup);
