@@ -124,7 +124,7 @@ DkColorSlider::DkColorSlider(QWidget *parent, qreal normedPos, QColor color, int
 
 	show();
 
-};
+}
 
 void DkColorSlider::paintEvent(QPaintEvent*) {
 
@@ -169,24 +169,22 @@ void DkColorSlider::setActive(bool isActive) {
 }
 
 DkColorSlider::~DkColorSlider() {
-};
+}
 
 QColor DkColorSlider::getColor() {
 
 	return mColor;
-};
+}
 
 qreal DkColorSlider::getNormedPos() {
 
 	return mNormedPos;
-
-};
+}
 
 void DkColorSlider::setNormedPos(qreal pos) {
 
 	mNormedPos = pos;
-
-};
+}
 
 
 void DkColorSlider::mousePressEvent(QMouseEvent *event) {
@@ -235,11 +233,10 @@ DkGradient::DkGradient(QWidget *parent)
 	mSliders = QVector<DkColorSlider*>();
 	init();
 
-};
+}
 
 DkGradient::~DkGradient() {
-
-};
+}
 
 void DkGradient::init() {
 
@@ -251,7 +248,7 @@ void DkGradient::init() {
 	updateGradient();
 
 
-};
+}
 
 void DkGradient::clearAllSliders() {
 
@@ -410,16 +407,13 @@ void DkGradient::updateGradient() {
 
 	for (int i = 0; i < mSliders.size(); i++) 
 		mGradient.setColorAt(mSliders.at(i)->getNormedPos(), mSliders.at(i)->getColor());
-
-
+	
 }
 
 QGradientStops DkGradient::getGradientStops() {
 
 	return mGradient.stops();
-
-};
-
+}
 
 void DkGradient::moveSlider(DkColorSlider* sender, int dragDistX, int yPos) {
 
@@ -492,15 +486,12 @@ void DkGradient::paintEvent(QPaintEvent*) {
 	
 	painter.fillRect(mHalfSliderWidth, 2, width() - mSliderWidth, height() - mClickAreaHeight, mGradient);
 	painter.drawRect(mHalfSliderWidth, 2, width() - mSliderWidth, height() - mClickAreaHeight);
-};
+}
 
 
+void DkGradient::mouseReleaseEvent(QMouseEvent *) {
 
-void DkGradient::mouseReleaseEvent(QMouseEvent *event) {
-	
-	
-	QPointF enterPos = event->pos();
-
+	// unused
 }
 
 void DkGradient::changeColor(DkColorSlider*) {
@@ -524,7 +515,7 @@ void DkGradient::activateSlider(DkColorSlider *sender) {
 
 	update();
 
-};
+}
 
 //
 DkTransferToolBar::DkTransferToolBar(QWidget * parent) 
@@ -589,18 +580,16 @@ DkTransferToolBar::DkTransferToolBar(QWidget * parent)
 	if (!mOldGradients.empty())
 		mGradient->setGradient(mOldGradients.first());
 
-};
+}
 
 DkTransferToolBar::~DkTransferToolBar() {
-
-	//saveSettings();
-};
+}
 
 
 void DkTransferToolBar::createIcons() {
 
 	// user needs to decide...
-	//this->setIconSize(QSize(Settings::param().display().iconSize, Settings::param().display().iconSize));
+	//this->setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(), DkSettingsManager::param().effectiveIconSize()));
 			
 	mToolBarIcons.resize(icon_toolbar_end);
 
@@ -631,7 +620,7 @@ void DkTransferToolBar::createIcons() {
 
 void DkTransferToolBar::saveSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup("Pseudo Color");
 
 	settings.beginWriteArray("oldGradients", mOldGradients.size());
@@ -656,7 +645,7 @@ void DkTransferToolBar::saveSettings() {
 
 void DkTransferToolBar::loadSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup("Pseudo Color");
 
 	int gSize = settings.beginReadArray("oldGradients");
@@ -711,20 +700,20 @@ void DkTransferToolBar::resizeEvent( QResizeEvent * event ) {
 
 	mGradient->resize(event->size().width() - mGradient->x(), 40);
 
-};
+}
 
 void DkTransferToolBar::insertSlider(qreal pos) {
 
 	mGradient->insertSlider(pos);
 
-};
+}
 
 void DkTransferToolBar::setImageMode(int mode) {
 
 	qDebug() << "and I received...";
 	applyImageMode(mode);
 
-};
+}
 
 void DkTransferToolBar::applyImageMode(int mode) {
 
@@ -763,12 +752,12 @@ void DkTransferToolBar::applyImageMode(int mode) {
 
 	connect(mChannelComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(changeChannel(int)));
 
-};
+}
 
 void DkTransferToolBar::pickColor(bool enabled) {
 
 	emit pickColorRequest(enabled);
-};
+}
 
 void DkTransferToolBar::enableTFCheckBoxClicked(int state) {
 
@@ -808,19 +797,16 @@ void DkTransferToolBar::enableToolBar(bool enable) {
 
 }
 
-
 void DkTransferToolBar::applyTF() {
 
 	QGradientStops stops = mGradient->getGradientStops();
 
 	emit colorTableChanged(stops);
-
-};
+}
 
 void DkTransferToolBar::changeChannel(int index) {
 
 	emit channelChanged(index);
-
 }
 
 void DkTransferToolBar::resetGradient() {
@@ -876,9 +862,9 @@ DkCropToolBar::DkCropToolBar(const QString & title, QWidget * parent /* = 0 */)
 	createLayout();
 	QMetaObject::connectSlotsByName(this);
 
-	setIconSize(QSize(Settings::param().display().iconSize, Settings::param().display().iconSize));
+	setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
 
-	if (Settings::param().display().toolbarGradient) 
+	if (DkSettingsManager::param().display().toolbarGradient) 
 		setObjectName("toolBarWithGradient");
 	else {
 		setStyleSheet("QToolBar{spacing: 3px; padding: 3px;}");
@@ -887,12 +873,14 @@ DkCropToolBar::DkCropToolBar(const QString & title, QWidget * parent /* = 0 */)
 }
 
 DkCropToolBar::~DkCropToolBar() {
+	
+	// save settings
 	saveSettings();
 }
 
 void DkCropToolBar::loadSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup("Crop");
 
 	mHorValBox->setValue(settings.value("AspectRatioHorizontal", 0).toInt());
@@ -906,7 +894,7 @@ void DkCropToolBar::loadSettings() {
 
 void DkCropToolBar::saveSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup("Crop");
 
 	settings.setValue("AspectRatioHorizontal", mHorValBox->value());
@@ -931,12 +919,12 @@ void DkCropToolBar::createIcons() {
 	mIcons[invert_icon].addPixmap(DkImage::loadIcon(":/nomacs/img/crop-invert-checked.svg"), QIcon::Normal, QIcon::On);
 	mIcons[info_icon] = DkImage::loadIcon(":/nomacs/img/info.svg");
 
-	if (!Settings::param().display().defaultIconColor) {
+	if (!DkSettingsManager::param().display().defaultIconColor) {
 		// now colorize all icons
 		for (int idx = 0; idx < mIcons.size(); idx++) {
 
-			mIcons[idx].addPixmap(DkImage::colorizePixmap(mIcons[idx].pixmap(Settings::param().display().iconSize, QIcon::Normal, QIcon::On), Settings::param().display().iconColor), QIcon::Normal, QIcon::On);
-			mIcons[idx].addPixmap(DkImage::colorizePixmap(mIcons[idx].pixmap(Settings::param().display().iconSize, QIcon::Normal, QIcon::Off), Settings::param().display().iconColor), QIcon::Normal, QIcon::Off);
+			mIcons[idx].addPixmap(DkImage::colorizePixmap(mIcons[idx].pixmap(DkSettingsManager::param().effectiveIconSize(this), QIcon::Normal, QIcon::On), DkSettingsManager::param().display().iconColor), QIcon::Normal, QIcon::On);
+			mIcons[idx].addPixmap(DkImage::colorizePixmap(mIcons[idx].pixmap(DkSettingsManager::param().effectiveIconSize(this), QIcon::Normal, QIcon::Off), DkSettingsManager::param().display().iconColor), QIcon::Normal, QIcon::Off);
 		}
 	}
 }
