@@ -40,6 +40,7 @@
 #include "DkActionManager.h"
 #include "DkStatusBar.h"
 #include "DkUtils.h"
+#include "DkBasicLoader.h"
 
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <QClipboard>
@@ -55,6 +56,7 @@
 #include <QDesktopWidget>
 #include <QSvgRenderer>
 #include <QMenu>
+#include <QtConcurrentRun>
 
 #include <qmath.h>
 #pragma warning(pop)		// no warnings from includes - end
@@ -73,7 +75,7 @@ DkViewPort::DkViewPort(QWidget *parent, Qt::WindowFlags flags) : DkBaseViewPort(
 
 	// try loading a custom file
 	mImgBg.load(QFileInfo(QApplication::applicationDirPath(), "bg.png").absoluteFilePath());
-	if (mImgBg.isNull() && Settings::param().global().showBgImage)
+	if (mImgBg.isNull() && DkSettingsManager::param().global().showBgImage)
 		mImgBg.load(":/nomacs/img/nomacs-bg.svg");
 
 	mRepeatZoomTimer->setInterval(20);
@@ -106,6 +108,7 @@ DkViewPort::DkViewPort(QWidget *parent, Qt::WindowFlags flags) : DkBaseViewPort(
 	addActions(am.fileActions().toList());
 	addActions(am.viewActions().toList());
 	addActions(am.editActions().toList());
+	addActions(am.manipulatorActions().toList());
 	addActions(am.sortActions().toList());
 	addActions(am.toolsActions().toList());
 	addActions(am.panelActions().toList());
@@ -129,6 +132,10 @@ DkViewPort::DkViewPort(QWidget *parent, Qt::WindowFlags flags) : DkBaseViewPort(
 	connect(am.action(DkActionManager::menu_file_reload), SIGNAL(triggered()), this, SLOT(reloadFile()));
 	connect(am.action(DkActionManager::menu_file_next), SIGNAL(triggered()), this, SLOT(loadNextFileFast()));
 	connect(am.action(DkActionManager::menu_file_prev), SIGNAL(triggered()), this, SLOT(loadPrevFileFast()));
+	connect(am.action(DkActionManager::menu_file_save), SIGNAL(triggered()), this, SLOT(saveFile()));
+	connect(am.action(DkActionManager::menu_file_save_as), SIGNAL(triggered()), this, SLOT(saveFileAs()));
+	connect(am.action(DkActionManager::menu_file_save_web), SIGNAL(triggered()), this, SLOT(saveFileWeb()));
+
 	connect(am.action(DkActionManager::menu_edit_rotate_cw), SIGNAL(triggered()), this, SLOT(rotateCW()));
 	connect(am.action(DkActionManager::menu_edit_rotate_ccw), SIGNAL(triggered()), this, SLOT(rotateCCW()));
 	connect(am.action(DkActionManager::menu_edit_rotate_180), SIGNAL(triggered()), this, SLOT(rotate180()));
@@ -144,6 +151,11 @@ DkViewPort::DkViewPort(QWidget *parent, Qt::WindowFlags flags) : DkBaseViewPort(
 	connect(am.action(DkActionManager::menu_view_movie_pause), SIGNAL(triggered(bool)), this, SLOT(pauseMovie(bool)));
 	connect(am.action(DkActionManager::menu_view_movie_prev), SIGNAL(triggered()), this, SLOT(previousMovieFrame()));
 	connect(am.action(DkActionManager::menu_view_movie_next), SIGNAL(triggered()), this, SLOT(nextMovieFrame()));
+	
+	for (auto action : am.manipulatorActions())
+		connect(action, SIGNAL(triggered()), this, SLOT(applyManipulator()));
+
+	connect(&mManipulatorWatcher, SIGNAL(finished()), this, SLOT(manipulatorApplied()));
 
 	// TODO:
 	// one could blur the canvas if a transparent GUI is present
@@ -157,10 +169,10 @@ DkViewPort::DkViewPort(QWidget *parent, Qt::WindowFlags flags) : DkBaseViewPort(
 
 DkViewPort::~DkViewPort() {
 
-	release();
-}
+	mController->closePlugin(false, true);
 
-void DkViewPort::release() {
+	mManipulatorWatcher.cancel();
+	mManipulatorWatcher.blockSignals(true);
 }
 
 void DkViewPort::createShortcuts() {
@@ -254,6 +266,9 @@ void DkViewPort::setImage(QImage newImg) {
 	emit movieLoadedSignal(false);
 	stopMovie();	// just to be sure
 
+	if (mManipulatorWatcher.isRunning())
+		mManipulatorWatcher.cancel();
+
 	//imgPyramid.clear();
 
 	mController->getOverview()->setImage(QImage());	// clear overview
@@ -270,10 +285,10 @@ void DkViewPort::setImage(QImage newImg) {
 	emit enableNoImageSignal(!newImg.isNull());
 
 	//qDebug() << "new image (mViewport) loaded,  size: " << newImg.size() << "channel: " << imgQt.format();
-	//qDebug() << "keep zoom is always: " << (Settings::param().display().keepZoom == DkSettings::zoom_always_keep);
+	//qDebug() << "keep zoom is always: " << (DkSettingsManager::param().display().keepZoom == DkSettings::zoom_always_keep);
 
-	if (!Settings::param().slideShow().moveSpeed && (Settings::param().display().keepZoom == DkSettings::zoom_never_keep ||
-		(Settings::param().display().keepZoom == DkSettings::zoom_keep_same_size && mOldImgRect != mImgRect)) ||
+	if (((!DkSettingsManager::param().slideShow().moveSpeed && DkSettingsManager::param().display().keepZoom == DkSettings::zoom_never_keep) ||
+		(DkSettingsManager::param().display().keepZoom == DkSettings::zoom_keep_same_size && mOldImgRect != mImgRect)) ||
 		mOldImgRect.isEmpty()) {
 		
 		mWorldMatrix.reset();
@@ -294,10 +309,11 @@ void DkViewPort::setImage(QImage newImg) {
 	mOldImgRect = mImgRect;
 	
 	// init fading
-	if (Settings::param().display().animationDuration && 
+	if (DkSettingsManager::param().display().animationDuration && 
+		DkSettingsManager::param().display().transition != DkSettingsManager::param().trans_appear && 
 		(mController->getPlayer()->isPlaying() ||
 			DkUtils::getMainWindow()->isFullScreen() ||
-			Settings::param().display().alwaysAnimate)) {
+			DkSettingsManager::param().display().alwaysAnimate)) {
 		mAnimationTimer->start();
 		mAnimationTime.start();
 	}
@@ -313,17 +329,25 @@ void DkViewPort::setImage(QImage newImg) {
 	update();
 
 	// draw a histogram from the image -> does nothing if the histogram is invisible
-	if (mController->getHistogram()) mController->getHistogram()->drawHistogram(newImg);
-	if (Settings::param().sync().syncMode == DkSettings::sync_mode_remote_display)
+	if (mController->getHistogram()) 
+		mController->getHistogram()->drawHistogram(newImg);
+	if (DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display)
 		tcpSendImage(true);
 
 	emit newImageSignal(&newImg);
 	emit zoomSignal((float)(mWorldMatrix.m11()*mImgMatrix.m11()*100));
 
 	// status info
-	DkStatusBarManager::instance().setMessage(QString::number(qRound((float)(mWorldMatrix.m11()*mImgMatrix.m11() * 100))) + "%", DkStatusBar::status_zoom_info);
-	DkStatusBarManager::instance().setMessage(DkUtils::formatToString(newImg.format()), DkStatusBar::status_format_info);
-	DkStatusBarManager::instance().setMessage(QString::number(newImg.width()) + " x " + QString::number(newImg.height()), DkStatusBar::status_dimension_info);
+	if (!newImg.isNull()) {
+		DkStatusBarManager::instance().setMessage(QString::number(qRound((float)(mWorldMatrix.m11()*mImgMatrix.m11() * 100))) + "%", DkStatusBar::status_zoom_info);
+		DkStatusBarManager::instance().setMessage(DkUtils::formatToString(newImg.format()), DkStatusBar::status_format_info);
+		DkStatusBarManager::instance().setMessage(QString::number(newImg.width()) + " x " + QString::number(newImg.height()), DkStatusBar::status_dimension_info);
+	}
+	else {
+		DkStatusBarManager::instance().setMessage("", DkStatusBar::status_zoom_info);
+		DkStatusBarManager::instance().setMessage("", DkStatusBar::status_format_info);
+		DkStatusBarManager::instance().setMessage("", DkStatusBar::status_dimension_info);
+	}
 }
 
 void DkViewPort::setThumbImage(QImage newImg) {
@@ -337,7 +361,7 @@ void DkViewPort::setThumbImage(QImage newImg) {
 
 	emit enableNoImageSignal(true);
 
-	if (!Settings::param().display().keepZoom || mImgRect != oldImgRect)
+	if (!DkSettingsManager::param().display().keepZoom || mImgRect != oldImgRect)
 		mWorldMatrix.reset();							
 
 	updateImageMatrix();
@@ -500,12 +524,12 @@ void DkViewPort::showZoom() {
 void DkViewPort::repeatZoom() {
 
 	qDebug() << "repeating...";
-	if ( (Settings::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton1) ||
-		(!Settings::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton2)) {
+	if ( (DkSettingsManager::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton1) ||
+		(!DkSettingsManager::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton2)) {
 		zoom(1.1f);
 	}
-	else if (	(!Settings::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton1) ||
-				( Settings::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton2)) {
+	else if (	(!DkSettingsManager::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton1) ||
+				( DkSettingsManager::param().display().invertZoom && QApplication::mouseButtons() == Qt::XButton2)) {
 		zoom(0.9f);
 	}
 	else {
@@ -515,7 +539,7 @@ void DkViewPort::repeatZoom() {
 
 void DkViewPort::toggleResetMatrix() {
 
-	Settings::param().display().keepZoom = !Settings::param().display().keepZoom;
+	DkSettingsManager::param().display().keepZoom = !DkSettingsManager::param().display().keepZoom;
 }
 
 void DkViewPort::updateImageMatrix() {
@@ -550,7 +574,7 @@ void DkViewPort::updateImageMatrix() {
 		mWorldMatrix.scale(scaleFactor, scaleFactor);
 		mWorldMatrix.translate(dx, dy);
 	}
-	else if (Settings::param().display().zoomToFit)
+	else if (DkSettingsManager::param().display().zoomToFit)
 		zoomToFit();
 
 }
@@ -596,7 +620,7 @@ void DkViewPort::tcpSynchronize(QTransform relativeMatrix) {
 
 	// check if we need a synchronization
 	if ((qApp->keyboardModifiers() == mAltMod ||
-		Settings::param().sync().syncMode != DkSettings::sync_mode_default || Settings::param().sync().syncActions) &&
+		DkSettingsManager::param().sync().syncMode != DkSettings::sync_mode_default || DkSettingsManager::param().sync().syncActions) &&
 		(hasFocus() || mController->hasFocus())) {
 		QPointF size = QPointF(geometry().width()/2.0f, geometry().height()/2.0f);
 		size = mWorldMatrix.inverted().map(size);
@@ -609,10 +633,10 @@ void DkViewPort::tcpSynchronize(QTransform relativeMatrix) {
 
 void DkViewPort::tcpForceSynchronize() {
 
-	int oldMode = Settings::param().sync().syncMode;
-	Settings::param().sync().syncMode = DkSettings::sync_mode_remote_display;
+	int oldMode = DkSettingsManager::param().sync().syncMode;
+	DkSettingsManager::param().sync().syncMode = DkSettings::sync_mode_remote_display;
 	tcpSynchronize();
-	Settings::param().sync().syncMode = oldMode;
+	DkSettingsManager::param().sync().syncMode = oldMode;
 }
 
 void DkViewPort::tcpShowConnections(QList<DkPeer*> peers) {
@@ -654,6 +678,10 @@ void DkViewPort::applyPlugin(DkPluginContainer* plugin, const QString& key) {
 	if (!plugin)
 		return;
 
+	DkBatchPluginInterface* bPlugin = plugin->batchPlugin();
+	if (bPlugin)
+		bPlugin->loadSettings();
+
 	QSharedPointer<DkImageContainerT> result = DkImageContainerT::fromImageContainer(plugin->plugin()->runPlugin(key, imageContainer()));
 	if (result) 
 		setEditedImage(result);
@@ -662,6 +690,116 @@ void DkViewPort::applyPlugin(DkPluginContainer* plugin, const QString& key) {
 #endif
 }
 
+void DkViewPort::saveFile() {
+	saveFileAs(true);
+}
+
+void DkViewPort::saveFileAs(bool silent) {
+
+	if (mLoader) {
+		mController->closePlugin(false);
+		mLoader->saveUserFileAs(getImage(), silent);
+	}
+}
+
+void DkViewPort::saveFileWeb() {
+	if (mLoader) {
+		mController->closePlugin(false);
+		mLoader->saveFileWeb(getImage());
+	}
+}
+
+void DkViewPort::applyManipulator() {
+
+	QAction* action = dynamic_cast<QAction*>(QObject::sender());
+
+	if (!action) {
+		qWarning() << "applyManipulator is not called from its action!";
+		return;
+	}
+
+	DkActionManager& am = DkActionManager::instance();
+	QSharedPointer<DkBaseManipulator> mpl = am.manipulatorManager().manipulator(action);
+
+	if (!mpl) {
+		qWarning() << "could not find manipulator for:" << action;
+		return;
+	}
+
+	// try to cast up
+	QSharedPointer<DkBaseManipulatorExt> mplExt = qSharedPointerDynamicCast<DkBaseManipulatorExt>(mpl);
+
+	// mark dirty
+	if (mManipulatorWatcher.isRunning() && mplExt && mActiveManipulator == mpl) {
+		mplExt->setDirty(true);
+		return;
+	}
+
+	if (mManipulatorWatcher.isRunning()) {
+		mController->setInfo(tr("Busy"));
+		return;
+	}
+
+	// show the dock (in case it's not shown yet)
+	if (mplExt) {
+		am.action(DkActionManager::menu_edit_image)->setChecked(true);
+	}
+
+	// undo last if it is an extended manipulator
+	QImage img;
+	if (mplExt && imageContainer()) {
+
+		auto l = imageContainer()->getLoader();
+		l->setMinHistorySize(3);	// increase the min history size to 3 for correctly popping back
+		if (l->lastEdit().editName() == mplExt->name()) {
+			imageContainer()->undo();
+		}
+		
+		img = imageContainer()->image();
+	}
+	else
+		img = getImage();
+
+	mManipulatorWatcher.setFuture(
+		QtConcurrent::run(
+			mpl.data(), 
+			&nmc::DkBaseManipulator::apply,
+			img));
+
+	mActiveManipulator = mpl;
+
+	emit showProgress(true, 500);
+}
+
+void DkViewPort::manipulatorApplied() {
+
+	DkGlobalProgress::instance().stop();
+
+	if (mManipulatorWatcher.isCanceled() || !mActiveManipulator) {
+		qDebug() << "manipulator applied - but it's canceled";
+		return;
+	}
+
+	// trigger again if it's dirty
+	QSharedPointer<DkBaseManipulatorExt> mplExt = qSharedPointerDynamicCast<DkBaseManipulatorExt>(mActiveManipulator);
+
+	// set the edited image
+	QImage img = mManipulatorWatcher.result();
+
+	if (!img.isNull())
+		setEditedImage(img, mActiveManipulator->name());
+	else
+		mController->setInfo(mActiveManipulator->errorMessage());
+
+	if (mplExt && mplExt->isDirty()) {
+		mplExt->setDirty(false);
+		mplExt->action()->trigger();
+		qDebug() << "triggering manipulator - it's dirty";
+	}
+
+	emit showProgress(false);
+}
+
 void DkViewPort::paintEvent(QPaintEvent* event) {
 
 	QPainter painter(viewport());
@@ -678,7 +816,7 @@ void DkViewPort::paintEvent(QPaintEvent* event) {
 		// don't interpolate if we are forced to, at 100% or we exceed the maximal interpolation level
 		if (!mForceFastRendering && // force?
 			fabs(mImgMatrix.m11()*mWorldMatrix.m11()-1.0f) > FLT_EPSILON && // @100% ?
-			mImgMatrix.m11()*mWorldMatrix.m11() <= (float)Settings::param().display().interpolateZoomLevel/100.0f) {	// > max zoom level
+			mImgMatrix.m11()*mWorldMatrix.m11() <= (float)DkSettingsManager::param().display().interpolateZoomLevel/100.0f) {	// > max zoom level
 			painter.setRenderHints(QPainter::SmoothPixmapTransform | QPainter::Antialiasing);
 		}
 
@@ -689,7 +827,7 @@ void DkViewPort::paintEvent(QPaintEvent* event) {
 			qDebug() << "added to image...";
 		}
 
-		if (Settings::param().display().transition == DkSettings::trans_swipe &&
+		if (DkSettingsManager::param().display().transition == DkSettings::trans_swipe &&
 			!mAnimationBuffer.isNull()) {
 		
 			painter.setRenderHints(QPainter::SmoothPixmapTransform | QPainter::Antialiasing, false);
@@ -702,7 +840,7 @@ void DkViewPort::paintEvent(QPaintEvent* event) {
 		}
 
 		// TODO: if fading is active we interpolate with background instead of the other image
-		double opacity = (Settings::param().display().transition == DkSettings::trans_fade) ? 1.0 - mAnimationValue : 1.0;
+		double opacity = (DkSettingsManager::param().display().transition == DkSettings::trans_fade) ? 1.0 - mAnimationValue : 1.0;
 		draw(painter, opacity);
 
 		if (!mAnimationBuffer.isNull() && mAnimationValue > 0) {
@@ -710,10 +848,10 @@ void DkViewPort::paintEvent(QPaintEvent* event) {
 			float oldOp = (float)painter.opacity();
 			
 			// fade transition
-			if (Settings::param().display().transition == DkSettings::trans_fade) {
+			if (DkSettingsManager::param().display().transition == DkSettings::trans_fade) {
 				painter.setOpacity(mAnimationValue);
 			}
-			else if (Settings::param().display().transition == DkSettings::trans_swipe) {
+			else if (DkSettingsManager::param().display().transition == DkSettings::trans_swipe) {
 			
 				double dx = mNextSwipe ? -width()*(1.0-mAnimationValue) : width()*(1.0-mAnimationValue);
 				QTransform swipeTransform;
@@ -733,7 +871,7 @@ void DkViewPort::paintEvent(QPaintEvent* event) {
 
 	// draw the cropping rect
 	// TODO: add a setting to hide this!
-	if (!mCropRect.isEmpty() && Settings::param().display().showCrop && imageContainer()) {
+	if (!mCropRect.isEmpty() && DkSettingsManager::param().display().showCrop && imageContainer()) {
 
 		// create path
 		QPainterPath path;
@@ -917,7 +1055,7 @@ void DkViewPort::dragLeaveEvent(QDragLeaveEvent *event) {
 void DkViewPort::mousePressEvent(QMouseEvent *event) {
 
 	// if zoom on wheel, the additional keys should be used for switching files
-	if (Settings::param().global().zoomOnWheel) {
+	if (DkSettingsManager::param().global().zoomOnWheel) {
 		if(event->buttons() == Qt::XButton1)
 			loadPrevFileFast();
 		else if(event->buttons() == Qt::XButton2)
@@ -983,9 +1121,9 @@ void DkViewPort::mouseMoveEvent(QMouseEvent *event) {
 		moveView(dxy/mWorldMatrix.m11());
 
 		// with shift also a hotkey for fast switching...
-		if ((Settings::param().sync().syncAbsoluteTransform &&
+		if ((DkSettingsManager::param().sync().syncAbsoluteTransform &&
 			event->modifiers() == (mAltMod | Qt::ShiftModifier)) || 
-			(!Settings::param().sync().syncAbsoluteTransform &&
+			(!DkSettingsManager::param().sync().syncAbsoluteTransform &&
 			event->modifiers() == (mAltMod))) {
 			
 			if (dxy.x() != 0 || dxy.y() != 0) {
@@ -1031,8 +1169,9 @@ void DkViewPort::wheelEvent(QWheelEvent *event) {
 	//if (event->modifiers() & altMod)
 	//	qDebug() << "ALT modifier";
 
-	if ((!Settings::param().global().zoomOnWheel && event->modifiers() != mCtrlMod) || 
-		(Settings::param().global().zoomOnWheel && (event->modifiers() & mCtrlMod || (event->orientation() == Qt::Horizontal && !(event->modifiers() & mAltMod))))) {
+	if ((!DkSettingsManager::param().global().zoomOnWheel && event->modifiers() != mCtrlMod) || 
+		(DkSettingsManager::param().global().zoomOnWheel && (event->modifiers() & mCtrlMod || 
+		(DkSettingsManager::param().global().horZoomSkips && event->orientation() == Qt::Horizontal && !(event->modifiers() & mAltMod))))) {
 
 		if (event->delta() < 0)
 			loadNextFileFast();
@@ -1224,14 +1363,11 @@ QMimeData * DkViewPort::createMime() const {
 	else if (!getImage().isNull())
 		mimeData->setImageData(getImage());
 
-	mimeData->setText(mLoader->filePath());
 	return mimeData;
 }
 
 void DkViewPort::copyImageBuffer() {
 
-	qDebug() << "copying...";
-
 	if (getImage().isNull())
 		return;
 
@@ -1246,7 +1382,7 @@ void DkViewPort::copyImageBuffer() {
 
 void DkViewPort::animateFade() {
 
-	mAnimationValue = 1.0f-(float)(mAnimationTime.elapsed()/1000.0)/Settings::param().display().animationDuration;
+	mAnimationValue = 1.0f-(float)(mAnimationTime.elapsed()/1000.0)/DkSettingsManager::param().display().animationDuration;
 	
 	// slow in - slow out
 	double speed = mAnimationValue > 0.5 ? fabs(1.0 - mAnimationValue) : fabs(mAnimationValue);
@@ -1318,7 +1454,7 @@ void DkViewPort::loadLena() {
 		toggleLena(DkUtils::getMainWindow()->isFullScreen());
 	}
 	else if (!ok) {
-		QMessageBox warningDialog(QApplication::activeWindow());
+		QMessageBox warningDialog(DkUtils::getMainWindow());
 		warningDialog.setIcon(QMessageBox::Warning);
 		warningDialog.setText(tr("you cannot cancel this"));
 		warningDialog.exec();
@@ -1349,7 +1485,7 @@ void DkViewPort::toggleLena(bool fullscreen) {
 
 	if (mLoader) {
 		if (fullscreen)
-			mLoader->load(":/nomacs/img/lena-full.jpg");
+			mLoader->load(":/nomacs/img/we.jpg");
 		else
 			mLoader->load(":/nomacs/img/lena.jpg");
 	}
@@ -1359,8 +1495,8 @@ void DkViewPort::settingsChanged() {
 
 	reloadFile();
 
-	mAltMod = Settings::param().global().altMod;
-	mCtrlMod = Settings::param().global().ctrlMod;
+	mAltMod = DkSettingsManager::param().global().altMod;
+	mCtrlMod = DkSettingsManager::param().global().ctrlMod;
 
 	mController->settingsChanged();
 }
@@ -1375,6 +1511,9 @@ void DkViewPort::setEditedImage(const QImage& newImg, const QString& editName) {
 		return;
 	}
 
+	if (mManipulatorWatcher.isRunning())
+		mManipulatorWatcher.cancel();
+
 	QSharedPointer<DkImageContainerT> imgC = mLoader->getCurrentImage();
 
 	if (!imgC)
@@ -1404,10 +1543,10 @@ void DkViewPort::setEditedImage(QSharedPointer<DkImageContainerT> img) {
 
 bool DkViewPort::unloadImage(bool fileChange) {
 
-	if (Settings::param().display().animationDuration > 0 && 
+	if (DkSettingsManager::param().display().animationDuration > 0 && 
 			(mController->getPlayer()->isPlaying() || 
 			DkUtils::getMainWindow()->isFullScreen() || 
-			Settings::param().display().alwaysAnimate)) {
+			DkSettingsManager::param().display().alwaysAnimate)) {
 		mAnimationBuffer = mImgStorage.getImage((float)(mImgMatrix.m11()*mWorldMatrix.m11()));
 		mFadeImgViewRect = mImgViewRect;
 		mFadeImgRect = mImgRect;
@@ -1454,8 +1593,8 @@ void DkViewPort::loadFile(const QString& filePath) {
 	else if (mLoader)
 		mLoader->load(filePath);
 
-	qDebug() << "sync mode: " << (Settings::param().sync().syncMode == DkSettings::sync_mode_remote_display);
-	if ((qApp->keyboardModifiers() == mAltMod || Settings::param().sync().syncMode == DkSettings::sync_mode_remote_display) && (hasFocus() || mController->hasFocus()) && mLoader->hasFile())
+	qDebug() << "sync mode: " << (DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display);
+	if ((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display) && (hasFocus() || mController->hasFocus()) && mLoader->hasFile())
 		tcpLoadFile(0, filePath);
 }
 
@@ -1477,7 +1616,7 @@ void DkViewPort::loadFile(int skipIdx) {
 		mLoader->changeFile(skipIdx);
 
 	// alt mod
-	if ((qApp->keyboardModifiers() == mAltMod || Settings::param().sync().syncMode == DkSettings::sync_mode_remote_display || Settings::param().sync().syncActions) && (hasFocus() || mController->hasFocus())) {
+	if ((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display || DkSettingsManager::param().sync().syncActions) && (hasFocus() || mController->hasFocus())) {
 		emit sendNewFileSignal((qint16)skipIdx);
 		qDebug() << "emitting load next";
 	}
@@ -1501,8 +1640,8 @@ void DkViewPort::loadFileFast(int skipIdx) {
 
 	mNextSwipe = skipIdx > 0;
 
-	if (!((qApp->keyboardModifiers() == mAltMod || Settings::param().sync().syncActions) &&
-		Settings::param().sync().syncMode == DkSettings::sync_mode_remote_control)) {
+	if (!((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncActions) &&
+		DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_control)) {
 		QApplication::sendPostedEvents();
 
 		int sIdx = skipIdx;
@@ -1532,8 +1671,8 @@ void DkViewPort::loadFileFast(int skipIdx) {
 		}
 	}	
 
-	if (((qApp->keyboardModifiers() == mAltMod || Settings::param().sync().syncActions) &&
-		Settings::param().sync().syncMode != DkSettings::sync_mode_remote_display) && 
+	if (((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncActions) &&
+		DkSettingsManager::param().sync().syncMode != DkSettings::sync_mode_remote_display) && 
 		(hasFocus() || 
 		mController->hasFocus())) {
 		emit sendNewFileSignal((qint16)skipIdx);
@@ -1551,7 +1690,7 @@ void DkViewPort::loadFirst() {
 	if (mLoader && !mTestLoaded)
 		mLoader->firstFile();
 
-	if ((qApp->keyboardModifiers() == mAltMod || Settings::param().sync().syncMode == DkSettings::sync_mode_remote_display || Settings::param().sync().syncActions) && (hasFocus() || mController->hasFocus()))
+	if ((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display || DkSettingsManager::param().sync().syncActions) && (hasFocus() || mController->hasFocus()))
 		emit sendNewFileSignal(SHRT_MIN);
 }
 
@@ -1563,33 +1702,33 @@ void DkViewPort::loadLast() {
 	if (mLoader && !mTestLoaded)
 		mLoader->lastFile();
 
-	if ((qApp->keyboardModifiers() == mAltMod || Settings::param().sync().syncMode == DkSettings::sync_mode_remote_display || Settings::param().sync().syncActions) && (hasFocus() || mController->hasFocus()))
+	if ((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display || DkSettingsManager::param().sync().syncActions) && (hasFocus() || mController->hasFocus()))
 		emit sendNewFileSignal(SHRT_MAX);
 
 }
 
 void DkViewPort::loadSkipPrev10() {
 
-	loadFileFast(-Settings::param().global().skipImgs);
+	loadFileFast(-DkSettingsManager::param().global().skipImgs);
 	//unloadImage();
 
 	//if (mLoader && !testLoaded)
-	//	mLoader->changeFile(-Settings::param().global().skipImgs, (parent->isFullScreen() && Settings::param().slideShow().silentFullscreen));
+	//	mLoader->changeFile(-DkSettingsManager::param().global().skipImgs, (parent->isFullScreen() && DkSettingsManager::param().slideShow().silentFullscreen));
 
 	if (qApp->keyboardModifiers() == mAltMod && (hasFocus() || mController->hasFocus()))
-		emit sendNewFileSignal((qint16)-Settings::param().global().skipImgs);
+		emit sendNewFileSignal((qint16)-DkSettingsManager::param().global().skipImgs);
 }
 
 void DkViewPort::loadSkipNext10() {
 
-	loadFileFast(Settings::param().global().skipImgs);
+	loadFileFast(DkSettingsManager::param().global().skipImgs);
 	//unloadImage();
 
 	//if (mLoader && !testLoaded)
-	//	mLoader->changeFile(Settings::param().global().skipImgs, (parent->isFullScreen() && Settings::param().slideShow().silentFullscreen));
+	//	mLoader->changeFile(DkSettingsManager::param().global().skipImgs, (parent->isFullScreen() && DkSettingsManager::param().slideShow().silentFullscreen));
 
 	if (qApp->keyboardModifiers() == mAltMod && (hasFocus() || mController->hasFocus()))
-		emit sendNewFileSignal((qint16)Settings::param().global().skipImgs);
+		emit sendNewFileSignal((qint16)DkSettingsManager::param().global().skipImgs);
 }
 
 void DkViewPort::tcpLoadFile(qint16 idx, QString filename) {
@@ -1598,8 +1737,8 @@ void DkViewPort::tcpLoadFile(qint16 idx, QString filename) {
 
 	// some hack: set the mode to default in order to prevent loops (if both are auto connected)
 	// should be mostly harmless
-	//int oldMode = Settings::param().sync().syncMode;
-	//Settings::param().sync().syncMode = DkSettings::sync_mode_receiveing_command;
+	//int oldMode = DkSettingsManager::param().sync().syncMode;
+	//DkSettingsManager::param().sync().syncMode = DkSettings::sync_mode_receiveing_command;
 
 	if (filename.isEmpty()) {
 
@@ -1627,7 +1766,7 @@ void DkViewPort::tcpLoadFile(qint16 idx, QString filename) {
 
 	qDebug() << "loading file: " << filename;
 
-	//Settings::param().sync().syncMode = oldMode;
+	//DkSettingsManager::param().sync().syncMode = oldMode;
 }
 
 QSharedPointer<DkImageContainerT> DkViewPort::imageContainer() const {
@@ -1739,13 +1878,6 @@ DkViewPortFrameless::DkViewPortFrameless(QWidget *parent, Qt::WindowFlags flags)
 }
 
 DkViewPortFrameless::~DkViewPortFrameless() {
-
-	release();
-}
-
-void DkViewPortFrameless::release() {
-
-	DkViewPort::release();
 }
 
 void DkViewPortFrameless::setImage(QImage newImg) {
@@ -1854,7 +1986,7 @@ void DkViewPortFrameless::draw(QPainter & painter, double) {
 	else {
 		QImage imgQt = mImgStorage.getImage((float)(mImgMatrix.m11()*mWorldMatrix.m11()));
 
-		if (Settings::param().display().tpPattern && imgQt.hasAlphaChannel()) {
+		if (DkSettingsManager::param().display().tpPattern && imgQt.hasAlphaChannel()) {
 
 			// don't scale the pattern...
 			QTransform scaleIv;
@@ -1938,7 +2070,7 @@ void DkViewPortFrameless::drawBackground(QPainter & painter) {
 void DkViewPortFrameless::drawFrame(QPainter & painter) {
 
 	// TODO: replace hasAlphaChannel with has alphaBorder
-	if (mImgStorage.hasImage() && mImgStorage.getImage().hasAlphaChannel() || !Settings::param().display().showBorder)	// braces
+	if ((mImgStorage.hasImage() && mImgStorage.getImage().hasAlphaChannel()) || !DkSettingsManager::param().display().showBorder)	// braces
 		return;
 
 	painter.setBrush(QColor(255, 255, 255, 200));
@@ -2152,13 +2284,6 @@ DkViewPortContrast::DkViewPortContrast(QWidget *parent, Qt::WindowFlags flags) :
 }
 
 DkViewPortContrast::~DkViewPortContrast() {
-
-	release();
-}
-
-void DkViewPortContrast::release() {
-
-	DkViewPort::release();
 }
 
 void DkViewPortContrast::changeChannel(int channel) {
@@ -2257,13 +2382,13 @@ void DkViewPortContrast::draw(QPainter & painter, double opacity) {
 
 	if (DkUtils::getMainWindow()->isFullScreen()) {
 		painter.setWorldMatrixEnabled(false);
-		painter.fillRect(QRect(QPoint(), size()), Settings::param().slideShow().backgroundColor);
+		painter.fillRect(QRect(QPoint(), size()), DkSettingsManager::param().slideShow().backgroundColor);
 		painter.setWorldMatrixEnabled(true);
 	}
 
 	QImage imgQt = mImgStorage.getImage((float)(mImgMatrix.m11()*mWorldMatrix.m11()));
 
-	if (Settings::param().display().tpPattern && imgQt.hasAlphaChannel()) {
+	if (DkSettingsManager::param().display().tpPattern && imgQt.hasAlphaChannel()) {
 
 		// don't scale the pattern...
 		QTransform scaleIv;
