@@ -108,7 +108,6 @@ DkFolderScrollBar::DkFolderScrollBar(QWidget* parent) : QSlider(Qt::Horizontal,
 }
 
 DkFolderScrollBar::~DkFolderScrollBar() {
-
 }
 
 // DkWidget stuff
@@ -130,12 +129,12 @@ bool DkFolderScrollBar::getCurrentDisplaySetting() {
 	if (!mDisplaySettingsBits)
 		return false;
 
-	if (Settings::param().app().currentAppMode < 0 || Settings::param().app().currentAppMode >= mDisplaySettingsBits->size()) {
-		qDebug() << "[WARNING] illegal app mode: " << Settings::param().app().currentAppMode;
+	if (DkSettingsManager::param().app().currentAppMode < 0 || DkSettingsManager::param().app().currentAppMode >= mDisplaySettingsBits->size()) {
+		qDebug() << "[WARNING] illegal app mode: " << DkSettingsManager::param().app().currentAppMode;
 		return false;
 	}
 
-	return mDisplaySettingsBits->testBit(Settings::param().app().currentAppMode);
+	return mDisplaySettingsBits->testBit(DkSettingsManager::param().app().currentAppMode);
 }
 
 void DkFolderScrollBar::updateDir(QVector<QSharedPointer<DkImageContainerT> > images) {
@@ -178,9 +177,9 @@ void DkFolderScrollBar::init() {
 
 	setMouseTracking(true);
 
-	mBgCol = (Settings::param().app().appMode == DkSettings::mode_frameless) ?
-		Settings::param().display().bgColorFrameless :
-		Settings::param().display().hudBgColor;
+	mBgCol = (DkSettingsManager::param().app().appMode == DkSettings::mode_frameless) ?
+		DkSettingsManager::param().display().bgColorFrameless :
+		DkSettingsManager::param().display().hudBgColor;
 
 	mShowing = false;
 	mHiding = false;
@@ -217,8 +216,8 @@ void DkFolderScrollBar::hide(bool saveSettings) {
 		animateOpacityDown();
 
 		// set display bit here too -> since the final call to setVisible takes a few seconds
-		if (saveSettings && mDisplaySettingsBits && mDisplaySettingsBits->size() > Settings::param().app().currentAppMode) {
-			mDisplaySettingsBits->setBit(Settings::param().app().currentAppMode, false);
+		if (saveSettings && mDisplaySettingsBits && mDisplaySettingsBits->size() > DkSettingsManager::param().app().currentAppMode) {
+			mDisplaySettingsBits->setBit(DkSettingsManager::param().app().currentAppMode, false);
 		}
 	}
 }
@@ -236,8 +235,8 @@ void DkFolderScrollBar::setVisible(bool visible, bool saveSettings) {
 	QWidget::setVisible(visible);
 	emit visibleSignal(visible);	// if this gets slow -> put it into hide() or show()
 
-	if (saveSettings && mDisplaySettingsBits && mDisplaySettingsBits->size() > Settings::param().app().currentAppMode) {
-		mDisplaySettingsBits->setBit(Settings::param().app().currentAppMode, visible);
+	if (saveSettings && mDisplaySettingsBits && mDisplaySettingsBits->size() > DkSettingsManager::param().app().currentAppMode) {
+		mDisplaySettingsBits->setBit(DkSettingsManager::param().app().currentAppMode, visible);
 	}
 }
 
@@ -292,7 +291,11 @@ void DkThumbsSaver::processDir(QVector<QSharedPointer<DkImageContainerT> > image
 	mCLoadIdx = 0;
 	mNumSaved = 0;
 
-	mPd = new QProgressDialog(tr("\nCreating thumbnails...\n") + images.first()->filePath(), tr("Cancel"), 0, (int)images.size(), QApplication::activeWindow());
+	mPd = new QProgressDialog(tr("\nCreating thumbnails...\n") + images.first()->filePath(), 
+		tr("Cancel"), 
+		0, 
+		(int)images.size(), 
+		DkUtils::getMainWindow());
 	mPd->setWindowTitle(tr("Thumbnails"));
 
 	//pd->setWindowModality(Qt::WindowModal);
@@ -330,7 +333,7 @@ void DkThumbsSaver::loadNext() {
 	if (mStop)
 		return;
 
-	int missing = Settings::param().resources().maxThumbsLoading-Settings::param().resources().numThumbsLoading;
+	int missing = DkSettingsManager::param().resources().maxThumbsLoading-DkSettingsManager::param().resources().numThumbsLoading;
 	int numLoading = mCLoadIdx+missing;
 	int force = (mForceSave) ? DkThumbNail::force_save_thumb : DkThumbNail::save_thumb;
 
@@ -354,7 +357,7 @@ DkFileSystemModel::DkFileSystemModel(QObject* parent /* = 0 */) : QFileSystemMod
 
 	// some custom settings
 	setRootPath(QDir::rootPath());
-	setNameFilters(Settings::param().app().fileFilters);
+	setNameFilters(DkSettingsManager::param().app().fileFilters);
 	setReadOnly(false);
 	//setSupportedDragActions(Qt::CopyAction | Qt::MoveAction);
 
@@ -418,6 +421,8 @@ DkExplorer::DkExplorer(const QString& title, QWidget* parent /* = 0 */, Qt::Wind
 }
 
 DkExplorer::~DkExplorer() {
+	
+	// save settings
 	writeSettings();
 }
 
@@ -556,7 +561,7 @@ void DkExplorer::closeEvent(QCloseEvent* event) {
 
 void DkExplorer::writeSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup(objectName());
 	
 	for (int idx = 0; idx < fileModel->columnCount(QModelIndex()); idx++) {
@@ -572,7 +577,7 @@ void DkExplorer::writeSettings() {
 
 void DkExplorer::readSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup(objectName());
 
 	for (int idx = 0; idx < fileModel->columnCount(QModelIndex()); idx++) {
@@ -633,13 +638,13 @@ void DkOverview::paintEvent(QPaintEvent *event) {
 
 		//draw the image's location
 		painter.setRenderHints(QPainter::SmoothPixmapTransform);
-		painter.setBrush(Settings::param().display().hudBgColor);
+		painter.setBrush(DkSettingsManager::param().display().hudBgColor);
 		painter.setPen(QColor(200, 200, 200));
 		//painter.drawRect(overviewRect);
 		painter.setOpacity(0.8f);
 		painter.drawImage(overviewImgRect, imgT, QRect(0, 0, imgT.width(), imgT.height()));
 
-		QColor col = Settings::param().display().highlightColor;
+		QColor col = DkSettingsManager::param().display().highlightColor;
 		col.setAlpha(255);
 		painter.setPen(col);
 		col.setAlpha(50);
@@ -682,7 +687,7 @@ void DkOverview::mouseReleaseEvent(QMouseEvent *event) {
 		QPointF lDxy = (cPos - currentViewPoint)/mWorldMatrix->m11()*panningSpeed;
 		emit moveViewSignal(lDxy);
 
-		if (event->modifiers() == Settings::param().global().altMod)
+		if (event->modifiers() == DkSettingsManager::param().global().altMod)
 			emit sendTransformSignal();
 	}
 
@@ -700,7 +705,7 @@ void DkOverview::mouseMoveEvent(QMouseEvent *event) {
 	mPosGrab = cPos;
 	emit moveViewSignal(dxy);
 
-	if (event->modifiers() == Settings::param().global().altMod)
+	if (event->modifiers() == DkSettingsManager::param().global().altMod)
 		emit sendTransformSignal();
 
 }
@@ -802,9 +807,9 @@ void DkZoomWidget::createLayout() {
 	mSlZoom->setMaximum(100);
 
 	QString styleString = "QDoubleSpinBox{margin: 0px; padding: 0px; color: " + 
-		DkUtils::colorToString(Settings::param().display().hudFgdColor) + 
+		DkUtils::colorToString(DkSettingsManager::param().display().hudFgdColor) + 
 		"; background-color: rgba(0,0,0,0); border: none; selection-background-color: " +
-		DkUtils::colorToString(Settings::param().display().highlightColor) + ";}";
+		DkUtils::colorToString(DkSettingsManager::param().display().highlightColor) + ";}";
 	//styleString += "QDoubleSpinBox::up-arrow, QDoubleSpinBox::down-arrow {width: 0px; heihgt: 0px;}";
 	//styleString += "QDoubleSpinBox::up-bottom, QDoubleSpinBox::down-bottom {width: 0px; heihgt: 0px;}";
 
@@ -967,7 +972,7 @@ QPixmap DkButton::createSelectedEffect(QPixmap* pm) {
 	if (!pm || pm->isNull())
 		return QPixmap();
 
-	return DkImage::colorizePixmap(*pm, Settings::param().display().highlightColor, 1.0f);
+	return DkImage::colorizePixmap(*pm, DkSettingsManager::param().display().highlightColor, 1.0f);
 }
 
 void DkButton::focusInEvent(QFocusEvent*) {
@@ -1139,11 +1144,11 @@ void DkFileInfoLabel::createLayout() {
 void DkFileInfoLabel::setVisible(bool visible, bool saveSettings) {
 
 	// nothing to display??
-	if (!Settings::param().slideShow().display.testBit(DkSettings::display_file_name) &&
-		!Settings::param().slideShow().display.testBit(DkSettings::display_creation_date) &&
-		!Settings::param().slideShow().display.testBit(DkSettings::display_file_rating) && visible) {
+	if (!DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_file_name) &&
+		!DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_creation_date) &&
+		!DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_file_rating) && visible) {
 			
-			QMessageBox infoDialog(QApplication::activeWindow());
+			QMessageBox infoDialog(DkUtils::getMainWindow());
 			infoDialog.setWindowTitle(tr("Info Box"));
 			infoDialog.setText(tr("All information fields are currently hidden.\nDo you want to show them again?"));
 			infoDialog.setIcon(QMessageBox::Information);
@@ -1157,16 +1162,16 @@ void DkFileInfoLabel::setVisible(bool visible, bool saveSettings) {
 				return;
 			}
 			else {
-				Settings::param().slideShow().display.setBit(DkSettings::display_file_name, true);
-				Settings::param().slideShow().display.setBit(DkSettings::display_creation_date, true);
-				Settings::param().slideShow().display.setBit(DkSettings::display_file_rating, true);
+				DkSettingsManager::param().slideShow().display.setBit(DkSettings::display_file_name, true);
+				DkSettingsManager::param().slideShow().display.setBit(DkSettings::display_creation_date, true);
+				DkSettingsManager::param().slideShow().display.setBit(DkSettings::display_file_rating, true);
 			}
 	}
 
 	DkFadeLabel::setVisible(visible, saveSettings);
-	mTitleLabel->setVisible(Settings::param().slideShow().display.testBit(DkSettings::display_file_name));
-	mDateLabel->setVisible(Settings::param().slideShow().display.testBit(DkSettings::display_creation_date));
-	mRatingLabel->setVisible(Settings::param().slideShow().display.testBit(DkSettings::display_file_rating));
+	mTitleLabel->setVisible(DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_file_name));
+	mDateLabel->setVisible(DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_creation_date));
+	mRatingLabel->setVisible(DkSettingsManager::param().slideShow().display.testBit(DkSettings::display_file_rating));
 
 	int height = 32;
 	if (mTitleLabel->isVisible())
@@ -1249,22 +1254,24 @@ DkPlayer::DkPlayer(QWidget* parent) : DkWidget(parent) {
 
 void DkPlayer::createLayout() {
 
+	int height = 50;
+
 	previousButton = new QPushButton(QIcon(":/nomacs/img/player-previous.svg"), "", this);
-	previousButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	previousButton->setIconSize(QSize(100, 50));
-	previousButton->setMaximumHeight(50);
+	//previousButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+	previousButton->setIconSize(QSize(2*height, height));
+	previousButton->setMaximumHeight(height);
 	previousButton->setToolTip(tr("Show previous image"));
 	previousButton->setObjectName("DkPlayerButton");
 	previousButton->setFlat(true);
 	connect(previousButton, SIGNAL(pressed()), this, SLOT(previous()));
 
 	QIcon icon;
-	icon.addPixmap(QIcon(":/nomacs/img/player-pause.svg").pixmap(100), QIcon::Normal, QIcon::On);
-	icon.addPixmap(QIcon(":/nomacs/img/player-play.svg").pixmap(100), QIcon::Normal, QIcon::Off);
+	icon.addPixmap(QIcon(":/nomacs/img/player-pause.svg").pixmap(2*height), QIcon::Normal, QIcon::On);
+	icon.addPixmap(QIcon(":/nomacs/img/player-play.svg").pixmap(2*height), QIcon::Normal, QIcon::Off);
 	playButton = new QPushButton(icon, "", this);
-	playButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	playButton->setIconSize(QSize(100, 50));
-	playButton->setMaximumHeight(50);
+	//playButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+	playButton->setIconSize(QSize(2*height, height));
+	playButton->setMaximumHeight(height);
 	playButton->setToolTip(tr("Play/Pause"));
 	playButton->setObjectName("DkPlayerButton");
 	playButton->setFlat(true);
@@ -1274,9 +1281,9 @@ void DkPlayer::createLayout() {
 	connect(playButton, SIGNAL(clicked(bool)), this, SLOT(play(bool)));
 
 	nextButton = new QPushButton(QIcon(":/nomacs/img/player-next.svg"), "",  this);
-	nextButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	nextButton->setIconSize(QSize(100, 50));
-	nextButton->setMaximumHeight(50);
+	//nextButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+	nextButton->setIconSize(QSize(2*height, height));
+	nextButton->setMaximumHeight(height);
 	nextButton->setToolTip(tr("Show next image"));
 	nextButton->setObjectName("DkPlayerButton");
 	nextButton->setFlat(true);
@@ -1284,7 +1291,7 @@ void DkPlayer::createLayout() {
 
 	// now add to mLayout
 	container = new QWidget(this);
-	QHBoxLayout *layout = new QHBoxLayout(container);
+	QHBoxLayout* layout = new QHBoxLayout(container);
 	layout->setContentsMargins(0,0,0,0);
 	layout->addStretch();
 	layout->addWidget(previousButton);
@@ -1297,7 +1304,7 @@ void DkPlayer::createLayout() {
 	l->addWidget(container);
 	l->addStretch();
 
-	setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+	//setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 
 }
 
@@ -1307,7 +1314,7 @@ void DkPlayer::init() {
 
 	// slide show
 	int timeToDisplayPlayer = 3000;
-	timeToDisplay = qRound(Settings::param().slideShow().time*1000);
+	timeToDisplay = qRound(DkSettingsManager::param().slideShow().time*1000);
 	playing = false;
 	displayTimer = new QTimer(this);
 	displayTimer->setInterval(timeToDisplay);
@@ -1349,7 +1356,7 @@ void DkPlayer::togglePlay() {
 
 void DkPlayer::startTimer() {
 	if (playing) {
-		displayTimer->setInterval(qRound(Settings::param().slideShow().time*1000));	// if it was updated...
+		displayTimer->setInterval(qRound(DkSettingsManager::param().slideShow().time*1000));	// if it was updated...
 		displayTimer->start();
 	}
 }
@@ -1390,8 +1397,8 @@ void DkPlayer::show(int ms) {
 	DkWidget::show();
 
 	// automatic showing, don't store it in the display bits
-	if (ms > 0 && mDisplaySettingsBits && mDisplaySettingsBits->size() > Settings::param().app().currentAppMode) {
-		mDisplaySettingsBits->setBit(Settings::param().app().currentAppMode, showPlayer);
+	if (ms > 0 && mDisplaySettingsBits && mDisplaySettingsBits->size() > DkSettingsManager::param().app().currentAppMode) {
+		mDisplaySettingsBits->setBit(DkSettingsManager::param().app().currentAppMode, showPlayer);
 	}
 }
  
@@ -1485,9 +1492,9 @@ DkEditableRect::DkEditableRect(const QRectF& rect, QWidget* parent, Qt::WindowFl
 
 	mPen = QPen(QColor(0, 0, 0, 255), 1);
 	mPen.setCosmetic(true);
-	mBrush = (Settings::param().app().appMode == DkSettings::mode_frameless) ?
-		Settings::param().display().bgColorFrameless :
-		Settings::param().display().hudBgColor;
+	mBrush = (DkSettingsManager::param().app().appMode == DkSettings::mode_frameless) ?
+		DkSettingsManager::param().display().bgColorFrameless :
+		DkSettingsManager::param().display().hudBgColor;
 
 	for (int idx = 0; idx < 8; idx++) {
 		mCtrlPoints.push_back(new DkTransformRect(idx, &this->mRect, this));
@@ -1604,7 +1611,7 @@ void DkEditableRect::updateCorner(int idx, const QPointF& point, Qt::KeyboardMod
 	if (changeState)
 		mState = scaling;
 
-	DkVector diag = (modifiers & Qt::ShiftModifier || mFixedDiag.x != 0 && mFixedDiag.y != 0) ? mOldDiag : DkVector();	// braces
+	DkVector diag = (modifiers & Qt::ShiftModifier || (mFixedDiag.x != 0 && mFixedDiag.y != 0)) ? mOldDiag : DkVector();	// braces
 	QPointF p = point;
 	
 	if ((modifiers & Qt::ControlModifier) == 0)
@@ -1752,7 +1759,7 @@ void DkEditableRect::mousePressEvent(QMouseEvent *event) {
 
 	// panning -> redirect to mViewport
 	if (event->buttons() == Qt::LeftButton && 
-		(event->modifiers() == Settings::param().global().altMod || mPanning)) {
+		(event->modifiers() == DkSettingsManager::param().global().altMod || mPanning)) {
 		event->setModifiers(Qt::NoModifier);	// we want a 'normal' action in the mViewport
 		event->ignore();
 		return;
@@ -1777,7 +1784,7 @@ void DkEditableRect::mousePressEvent(QMouseEvent *event) {
 void DkEditableRect::mouseMoveEvent(QMouseEvent *event) {
 
 	// panning -> redirect to mViewport
-	if (event->modifiers() == Settings::param().global().altMod ||
+	if (event->modifiers() == DkSettingsManager::param().global().altMod ||
 		mPanning) {
 		
 		if (event->buttons() != Qt::LeftButton)
@@ -1886,7 +1893,7 @@ void DkEditableRect::mouseReleaseEvent(QMouseEvent *event) {
 
 	// panning -> redirect to mViewport
 	if (event->buttons() == Qt::LeftButton && 
-		(event->modifiers() == Settings::param().global().altMod || mPanning)) {
+		(event->modifiers() == DkSettingsManager::param().global().altMod || mPanning)) {
 		setCursor(Qt::OpenHandCursor);
 		event->setModifiers(Qt::NoModifier);
 		event->ignore();
@@ -2098,8 +2105,20 @@ DkHistogram::DkHistogram(QWidget *parent) : DkWidget(parent){
 	
 	setObjectName("DkHistogram");
 	setMinimumWidth(265);
-	setMinimumHeight(130);
+	setMinimumHeight(142);
 	setCursor(Qt::ArrowCursor);
+	loadSettings();
+
+	//create context menu
+	QAction* showStats = new QAction(tr("Show Statistics"), this);
+	showStats->setObjectName("toggleStats");
+	showStats->setCheckable(true);
+	showStats->setChecked(mDisplayMode == DisplayMode::histogram_mode_extended);
+
+	mContextMenu = new QMenu(tr("Histogram Settings"));
+	mContextMenu->addAction(showStats);
+
+	QMetaObject::connectSlotsByName(this);
 }
 
 DkHistogram::~DkHistogram() {
@@ -2111,36 +2130,109 @@ DkHistogram::~DkHistogram() {
 void DkHistogram::paintEvent(QPaintEvent*) {
 
 	QPainter painter(this);
-	//painter.setPen(QColor(200, 200, 200));
 	painter.fillRect(1, 1, width(), height(), mBgCol);
-	//painter.drawRect(1, 1, width(), height());
 
-	int margin = 5;
-	int binHeight = height() - margin * 2;
+	int numTextLines;
+	if (mDisplayMode == DisplayMode::histogram_mode_simple) {
+		numTextLines = 0;
+	} else {
+		// histogram_mode_extended has 2 lines of text
+		numTextLines = 2;
+	}
 
-	if(mIsPainted && mMaxValue > 0){
+	const int margin = 5;
+	const int TEXT_SIZE = 12 + 1;  //FIXME just guessed
+	const int textHeight = numTextLines * TEXT_SIZE + margin;
+
+	int binHeight = height() - margin * 2 - textHeight;
+	int binBottom = height() - margin - textHeight;
+
+	//draw Histogram
+	if (mIsPainted && mMaxValue > 0) {
 		
-		for(int x = 0; x < 256; x++){
+		for (int x = 0; x < 256; x++) {
 			
 			// get bounded values
 			int rLineHeight = qMax(qMin(qRound((float)mHist[0][x] * binHeight * mScaleFactor/mMaxValue), binHeight), 0);
 			int gLineHeight = qMax(qMin(qRound((float)mHist[1][x] * binHeight * mScaleFactor/mMaxValue), binHeight), 0);
 			int bLineHeight = qMax(qMin(qRound((float)mHist[2][x] * binHeight * mScaleFactor/mMaxValue), binHeight), 0);
-			int maxLineHeight = qMax(qMax(rLineHeight, gLineHeight), bLineHeight); // (rLineHeight > gLineHeight) ? ((rLineHeight > bLineHeight) ? rLineHeight : bLineHeight) : ((gLineHeight > bLineHeight) ? gLineHeight : bLineHeight);
+			int maxLineHeight = qMax(qMax(rLineHeight, gLineHeight), bLineHeight);
 
 			painter.setCompositionMode(QPainter::CompositionMode_Clear);
 			painter.setPen(Qt::black);
-			painter.drawLine(QPoint(x + margin, height() - margin), QPoint(x + margin, height()-margin - maxLineHeight));
+			painter.drawLine(QPoint(x + margin, binBottom), QPoint(x + margin, binBottom - maxLineHeight));
 
 			painter.setCompositionMode(QPainter::CompositionMode_Screen);
 			painter.setPen(Qt::red);
-			painter.drawLine(QPoint(x+margin, height()-margin), QPoint(x+margin, height()-margin-rLineHeight));
+			painter.drawLine(QPoint(x+margin, binBottom), QPoint(x+margin, binBottom - rLineHeight));
 			painter.setPen(Qt::green);
-			painter.drawLine(QPoint(x+margin, height()-margin), QPoint(x+margin, height()-margin-gLineHeight));
+			painter.drawLine(QPoint(x+margin, binBottom), QPoint(x+margin, binBottom - gLineHeight));
 			painter.setPen(Qt::blue);
-			painter.drawLine(QPoint(x+margin, height()-margin), QPoint(x+margin, height()-margin-bLineHeight));
+			painter.drawLine(QPoint(x+margin, binBottom), QPoint(x+margin, binBottom - bLineHeight));
 		}
 	}
+
+    if (mDisplayMode == DisplayMode::histogram_mode_extended) {
+
+		//draw histogram text
+        double megaPixels = (double)mNumPixels * 10.0e-7;
+        painter.setPen(QColor(255, 255, 255, 200));
+
+        QString histText1("Pixels: %1\tMPix: %2");
+        painter.drawText(QPoint(margin, height() - 2 * TEXT_SIZE + margin),
+                         histText1.arg(mNumPixels, 10, 10)
+                                  .arg(megaPixels, 10, 'f', 2));
+
+        if (mMinBinValue < 256) {
+            //gray image statistics
+            QString histText2("Min: %1\tMax: %2\tValue Count: %3");
+            painter.drawText(QPoint(margin, height() - 1 * TEXT_SIZE + margin),
+                             histText2.arg(mMinBinValue, 5, 10)
+                                      .arg(mMaxBinValue, 5, 10)
+                                      .arg(mNumDistinctValues, 5, 10));
+        } else {
+            //color image statistics
+            double blackPct = 100.0 * (double)mNumZeroPixels / (double)mNumPixels;
+            double whitePct = 100.0 * (double)mNumSaturatedPixels / (double)mNumPixels;
+            double goodPct = 100.0 * (double)(mNumPixels - mNumZeroPixels - mNumSaturatedPixels) / (double)mNumPixels;
+
+            QString histText2("Black:  %1\tGood: %3\tWhite: %2");
+            painter.drawText(QPoint(margin, height() - 1 * TEXT_SIZE + margin),
+                             histText2.arg(blackPct, 5, 'f', 1)
+                                      .arg(whitePct, 5, 'f', 1)
+                                      .arg(goodPct, 5, 'f', 1));
+
+        }
+    }
+}
+
+void DkHistogram::contextMenuEvent(QContextMenuEvent * event) {
+
+	mContextMenu->exec(event->globalPos());
+	event->accept();
+
+	// do not pass it on
+	//DkWidget::contextMenuEvent(event);
+}
+
+void DkHistogram::on_toggleStats_triggered(bool show) {
+	
+	mDisplayMode = (show) ? DisplayMode::histogram_mode_extended : DisplayMode::histogram_mode_simple;
+	DkSettingsManager::param().display().histogramStyle = (int)mDisplayMode;
+	update();
+}
+
+void DkHistogram::loadSettings() {
+
+	int styleSetting = DkSettingsManager::param().display().histogramStyle;
+	DisplayMode maybeMode = static_cast<DisplayMode>(styleSetting);
+	if(maybeMode == DisplayMode::histogram_mode_simple ||
+	   maybeMode == DisplayMode::histogram_mode_extended){
+
+		mDisplayMode = maybeMode;
+	} else {
+		mDisplayMode = DisplayMode::histogram_mode_simple;
+	}
 }
 
 /**
@@ -2156,17 +2248,21 @@ void DkHistogram::drawHistogram(QImage imgQt) {
 
 	DkTimer dt;
 
-#ifdef WITH_OPENCV
-	
-	int histValues[3][256];
+	//clear histogram values
+	mNumZeroPixels = 0;
+	mNumSaturatedPixels = 0;
+	mMaxBinValue = -1;
+	mMinBinValue = 256;
+	mMaxValue = 0;
+	mNumPixels = imgQt.width() * imgQt.height();
 
 	for (int idx = 0; idx < 256; idx++) {
-		histValues[0][idx] = 0;
-		histValues[1][idx] = 0;
-		histValues[2][idx] = 0;
+		mHist[0][idx] = 0;
+		mHist[1][idx] = 0;
+		mHist[2][idx] = 0;
 	}
-	
 
+	// count pixel- and total values, for
 	// 8 bit images
 	if (imgQt.depth() == 8) {
 
@@ -2178,28 +2274,38 @@ void DkHistogram::drawHistogram(QImage imgQt) {
 
 			for (int cIdx = 0; cIdx < imgQt.width(); cIdx++, pixel++) {
 
-				histValues[0][*pixel]++;
-				histValues[1][*pixel]++;
-				histValues[2][*pixel]++;
+				mHist[0][*pixel]++;
+				mHist[1][*pixel]++;
+				mHist[2][*pixel]++;
+
+				if (*pixel == 255) mNumSaturatedPixels++;
+				if (*pixel < mMinBinValue) mMinBinValue = *pixel;
+				if (*pixel > mMaxBinValue) mMaxBinValue = *pixel;
 			}
 		}
 	}
 	// 24 bit images
 	else if (imgQt.depth() == 24) {
 		
-		qDebug() << "24 bit histogram -------------------";
-
-		// TODO: not tested!!
 		for (int rIdx = 0; rIdx < imgQt.height(); rIdx++) {
 
 			const unsigned char* pixel = imgQt.constScanLine(rIdx);
-
 			for (int cIdx = 0; cIdx < imgQt.width(); cIdx++) {
 
 				// If I understood the api correctly, the first bits are 0 if we have 24bpp & < 8 bits per channel
-				histValues[0][*pixel]++; pixel++;
-				histValues[1][*pixel]++; pixel++;
-				histValues[2][*pixel]++; pixel++;
+				unsigned char pixR = *pixel;
+				mHist[0][*pixel]++; pixel++;
+				unsigned char pixG = *pixel;
+				mHist[1][*pixel]++; pixel++;
+				unsigned char pixB = *pixel;
+				mHist[2][*pixel]++; pixel++;
+
+				if (pixR == 0 && pixG == 0 && pixB == 0) {
+					mNumZeroPixels++;
+				}
+				else if (pixR == 255 && pixG == 255 && pixB == 255) {
+					mNumSaturatedPixels++;
+				}
 			}
 		}
 	}
@@ -2211,36 +2317,42 @@ void DkHistogram::drawHistogram(QImage imgQt) {
 			const QRgb* pixel = (QRgb*)(imgQt.constScanLine(rIdx));
 	
 			for (int cIdx = 0; cIdx < imgQt.width(); cIdx++, pixel++) {
+				size_t pixR = static_cast<size_t>(qRed(*pixel));
+				size_t pixG = static_cast<size_t>(qGreen(*pixel));
+				size_t pixB = static_cast<size_t>(qBlue(*pixel));
 
-				histValues[0][qRed(*pixel)]++;
-				histValues[1][qGreen(*pixel)]++;
-				histValues[2][qBlue(*pixel)]++;
+				mHist[0][pixR]++;
+				mHist[1][pixG]++;
+				mHist[2][pixB]++;
+
+				if (pixR == 0 && pixG == 0 && pixB == 0) {
+					mNumZeroPixels++;
+				}
+				else if (pixR == 255 && pixG == 255 && pixB == 255) {
+					mNumSaturatedPixels++;
+				}
 			}
 		}
 	}
 
-	int maxHistValue = 0;
+	// determine extreme values from the histogram
+	mNumDistinctValues = 0;
 
-	for (int idx = 0; idx < 256; idx++) {
-		
-		if (histValues[0][idx] > maxHistValue)
-			maxHistValue = histValues[0][idx];
-		if (histValues[1][idx] > maxHistValue)
-			maxHistValue = histValues[1][idx];
-		if (histValues[2][idx] > maxHistValue)
-			maxHistValue = histValues[2][idx];
-	}
+    for (int idx = 0; idx < 256; idx++) {
+        if (mHist[0][idx] > mMaxValue)
+            mMaxValue = mHist[0][idx];
+        if (mHist[1][idx] > mMaxValue)
+            mMaxValue = mHist[1][idx];
+        if (mHist[2][idx] > mMaxValue)
+            mMaxValue = mHist[2][idx];
+
+        if (mHist[0][idx] || mHist[1][idx] || mHist[2][idx]){
+            mNumDistinctValues++;
+        }
+    }
 
-	setMaxHistogramValue(maxHistValue);
-	updateHistogramValues(histValues);
 	setPainted(true);
-
-#else
-	setPainted(false);
-#endif
-	
 	qDebug() << "drawing the histogram took me: " << dt;
-
 	update();
 }
 
@@ -2392,13 +2504,13 @@ void DkImageLabel::createLayout() {
 	imageLabel = new QLabel(this);
 	imageLabel->setFixedSize(mThumbSize, mThumbSize);
 	imageLabel->setScaledContents(true);
-	imageLabel->setStyleSheet("QLabel{margin: 0 0 0 0; padding: 0 0 0 0; border: 1px solid " + DkUtils::colorToString(Settings::param().display().hudBgColor) + ";}");
+	imageLabel->setStyleSheet("QLabel{margin: 0 0 0 0; padding: 0 0 0 0; border: 1px solid " + DkUtils::colorToString(DkSettingsManager::param().display().hudBgColor) + ";}");
 
-	QColor cA = Settings::param().display().highlightColor;
+	QColor cA = DkSettingsManager::param().display().highlightColor;
 	cA.setAlpha(100);
 	highLightLabel = new QLabel(this);
 	highLightLabel->setFixedSize(mThumbSize, mThumbSize);
-	highLightLabel->setStyleSheet("QLabel{background: " + DkUtils::colorToString(cA) + "; border: 1px solid " + DkUtils::colorToString(Settings::param().display().highlightColor) + ";}");
+	highLightLabel->setStyleSheet("QLabel{background: " + DkUtils::colorToString(cA) + "; border: 1px solid " + DkUtils::colorToString(DkSettingsManager::param().display().highlightColor) + ";}");
 	highLightLabel->hide();
 
 	removeFileButton = new QPushButton(QIcon(":/nomacs/img/close.svg"), tr(""), this);
@@ -2451,13 +2563,13 @@ void DkImageLabel::removeFileFromList() {
 	imageLabel->hide();
 	//highLightLabel->hide();
 	removeFileButton->hide();
-	highLightLabel->setStyleSheet("QLabel{background: " + DkUtils::colorToString(Settings::param().display().hudBgColor) + "; border: 1px solid black;}");
+	highLightLabel->setStyleSheet("QLabel{background: " + DkUtils::colorToString(DkSettingsManager::param().display().hudBgColor) + "; border: 1px solid black;}");
 	highLightLabel->show();
 
-	for (int idx = 0; idx < Settings::param().global().recentFiles.size(); idx++) {
+	for (int idx = 0; idx < DkSettingsManager::param().global().recentFiles.size(); idx++) {
 
-		if (thumb->getFilePath() == Settings::param().global().recentFiles.at(idx))
-			Settings::param().global().recentFiles.removeAt(idx);
+		if (thumb->getFilePath() == DkSettingsManager::param().global().recentFiles.at(idx))
+			DkSettingsManager::param().global().recentFiles.removeAt(idx);
 	}
 }
 
@@ -2597,10 +2709,10 @@ void DkRecentFilesWidget::updateFileList() {
 	recentFiles.clear();
 	//recentFolders.clear();
 
-	for (const QString& filePath : Settings::param().global().recentFiles)
+	for (const QString& filePath : DkSettingsManager::param().global().recentFiles)
 		recentFiles.append(QFileInfo(filePath));
-	//for (int idx = 0; idx < Settings::param().global().recentFolders.size(); idx++)
-	//	recentFolders.append(QFileInfo(Settings::param().global().recentFolders.at(idx)));
+	//for (int idx = 0; idx < DkSettingsManager::param().global().recentFolders.size(); idx++)
+	//	recentFolders.append(QFileInfo(DkSettingsManager::param().global().recentFolders.at(idx)));
 
 	updateFiles();
 	//updateFolders();
@@ -2626,7 +2738,7 @@ void DkRecentFilesWidget::updateFiles() {
 		fileLabels.at(rFileIdx)->hide();
 
 		// remove files which we can't load to keep the list clean...
-		Settings::param().global().recentFiles.removeAll(fileLabels.at(rFileIdx)->getThumb()->getFilePath());		// remove recent files which we could not load...
+		DkSettingsManager::param().global().recentFiles.removeAll(fileLabels.at(rFileIdx)->getThumb()->getFilePath());		// remove recent files which we could not load...
 	}
 
 	if (!fileLabels.empty())
@@ -2643,9 +2755,9 @@ void DkRecentFilesWidget::updateFiles() {
 		connect(cLabel, SIGNAL(loadFileSignal(const QString&)), this, SIGNAL(loadFileSignal(const QString&)));
 		cLabel->getThumb()->fetchThumb(DkThumbNailT::force_exif_thumb);
 	}
-	else {
-		qDebug() << "[Recent Files] loading stopped at" << rFileIdx << "history size:" << recentFiles.size();
-	}
+	//else {
+	//	qDebug() << "[Recent Files] loading stopped at" << rFileIdx << "history size:" << recentFiles.size();
+	//}
 
 	update();
 }
@@ -2854,13 +2966,17 @@ void DkProgressBar::setVisibleTimed(bool visible, int time) {
 
 void DkProgressBar::paintEvent(QPaintEvent *) {
 
+	QStyleOption opt;
+	opt.init(this);
+
 	QPainter p(this);
+	style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
 	p.setPen(Qt::NoPen);
 
 	if (parentWidget() && DkUtils::getMainWindow()->isFullScreen())
-		p.fillRect(QRect(QPoint(), size()), Settings::param().slideShow().backgroundColor);
+		p.fillRect(QRect(QPoint(), size()), DkSettingsManager::param().slideShow().backgroundColor);
 
-	p.setBrush(Settings::param().display().highlightColor);
+	p.setBrush(DkSettingsManager::param().display().highlightColor);
 
 	if (value() != minimum()) {
 
@@ -2914,12 +3030,14 @@ void DkProgressBar::animatePoint(double& xVal) {
 }
 
 // DkGenericProfileWidget --------------------------------------------------------------------
-DkGenericProfileWidget::DkGenericProfileWidget(const QString& name, QWidget* parent) : DkNamedWidget(name, parent) {
+DkGenericProfileWidget::DkGenericProfileWidget(const QString& name, QWidget* parent, const QString& settingsPath) : DkNamedWidget(name, parent) {
 
+	mSettingsPath = settingsPath.isEmpty() ? DkSettingsManager::param().settingsPath() : settingsPath;
 }
 
 DkGenericProfileWidget::~DkGenericProfileWidget() {
 
+	// save settings
 	for (int idx = 0; idx < mProfileList->count(); idx++) {
 		saveSettings(mProfileList->itemText(idx));
 	}
@@ -2976,11 +3094,11 @@ void DkGenericProfileWidget::createLayout() {
 
 QStringList DkGenericProfileWidget::loadProfileStrings() const {
 
-	QSettings& settings = Settings::instance().getSettings();
+	QSettings s(mSettingsPath, QSettings::IniFormat);
 
-	settings.beginGroup(mSettingsGroup);
-	QStringList modelStrings = settings.childGroups();
-	settings.endGroup();
+	s.beginGroup(mSettingsGroup);
+	QStringList modelStrings = s.childGroups();
+	s.endGroup();
 
 	qDebug() << "profile settings of group: " << mSettingsGroup;
 
@@ -2991,13 +3109,13 @@ void DkGenericProfileWidget::deleteCurrentSetting() {
 
 	QString modelName = mProfileList->currentText();
 
-	QSettings& settings = Settings::instance().getSettings();
+	QSettings s(mSettingsPath, QSettings::IniFormat);
 
-	settings.beginGroup(mSettingsGroup);
-	settings.beginGroup(modelName);
-	settings.remove("");	// remove all group entries
-	settings.endGroup();
-	settings.endGroup();
+	s.beginGroup(mSettingsGroup);
+	s.beginGroup(modelName);
+	s.remove("");	// remove all group entries
+	s.endGroup();
+	s.endGroup();
 
 	// update list
 	mProfileList->removeItem(mProfileList->currentIndex());
@@ -3062,18 +3180,18 @@ void DkGenericProfileWidget::activate(bool active) {
 
 void DkGenericProfileWidget::setDefaultModel() const {
 
-	QSettings& settings = Settings::instance().getSettings();
-	settings.beginGroup(mSettingsGroup);
-	settings.setValue("DefaultProfileString", mProfileList->currentText());
-	settings.endGroup();
+	QSettings s(mSettingsPath, QSettings::IniFormat);
+	s.beginGroup(mSettingsGroup);
+	s.setValue("DefaultProfileString", mProfileList->currentText());
+	s.endGroup();
 }
 
 QString DkGenericProfileWidget::loadDefaultProfileString() const {
 
-	QSettings& settings = Settings::instance().getSettings();
-	settings.beginGroup(mSettingsGroup);
-	QString defaultString = settings.value("DefaultProfileString", "").toString();
-	settings.endGroup();
+	QSettings s(mSettingsPath, QSettings::IniFormat);
+	s.beginGroup(mSettingsGroup);
+	QString defaultString = s.value("DefaultProfileString", "").toString();
+	s.endGroup();
 
 	return defaultString;
 }
@@ -3095,6 +3213,30 @@ void DkGenericProfileWidget::paintEvent(QPaintEvent* ev) {
 		DkNamedWidget::paintEvent(ev);
 }
 
+// DkTabEntryWidget --------------------------------------------------------------------
+DkTabEntryWidget::DkTabEntryWidget(const QIcon& icon, const QString& text, QWidget* parent) : QPushButton(text, parent) {
+
+	setObjectName("DkTabEntryWidget");
+
+	QPixmap pm = DkImage::colorizePixmap(icon.pixmap(100), QColor(255, 255, 255));
+	setIcon(pm);
+	setIconSize(pm.size());
+
+	setFlat(true);
+	setCheckable(true);
+}
+
+void DkTabEntryWidget::paintEvent(QPaintEvent *event) {
+
+	// fixes stylesheets which are not applied to custom widgets
+	QStyleOption opt;
+	opt.init(this);
+	QPainter p(this);
+	style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+
+	QPushButton::paintEvent(event);
+}
+
 }
 
 
