@@ -60,6 +60,7 @@ class QSlider;
 class QGridLayout;
 class QVBoxLayout;
 class QSvgRenderer;
+class QSettings;
 
 namespace nmc {
 
@@ -225,7 +226,7 @@ class DkPlayer : public DkWidget {
 
 public:
 	enum {
-		play_action,	// if more actions are to be assigned
+		play_action = 0,	// if more actions are to be assigned
 	};
 
 	DkPlayer(QWidget* parent = 0);
@@ -366,7 +367,7 @@ protected:
 
 };
 
-class DkExplorer : public DkDockWidget {
+class DllCoreExport DkExplorer : public DkDockWidget {
 	Q_OBJECT
 
 public:
@@ -641,7 +642,7 @@ protected:
  * Uses animation from the path
  * to display it in a DkLabel.
  */
-class DllGuiExport DkAnimationLabel : public DkLabel {
+class DllCoreExport DkAnimationLabel : public DkLabel {
 
 public:
 	DkAnimationLabel(QString animationPath = QString(), QWidget* parent = 0);
@@ -664,26 +665,49 @@ class DkHistogram : public DkWidget {
 	Q_OBJECT
 	
 public:
+	enum class DisplayMode {
+		histogram_mode_simple = 0,      /// shows just the histogram
+		histogram_mode_extended = 1,    /// shows histogram and data
+		histogram_mode_end = 2,
+	};
+
+
 	DkHistogram(QWidget *parent);
 	~DkHistogram();
+
 	void drawHistogram(QImage img);
 	void clearHistogram();
 	void setMaxHistogramValue(int maxValue);
 	void updateHistogramValues(int histValues[][256]);
 	void setPainted(bool isPainted);
 
+public slots:
+	void on_toggleStats_triggered(bool show);
+
 protected:
-	virtual void mousePressEvent(QMouseEvent *event);
-	virtual void mouseMoveEvent(QMouseEvent *event);
-	virtual void mouseReleaseEvent(QMouseEvent *event);
-	virtual void paintEvent(QPaintEvent* event);
+	virtual void mousePressEvent(QMouseEvent *event) override;
+	virtual void mouseMoveEvent(QMouseEvent *event) override;
+	virtual void mouseReleaseEvent(QMouseEvent *event) override;
+	virtual void paintEvent(QPaintEvent* event) override;
+	virtual void contextMenuEvent(QContextMenuEvent *event) override;
+
+	void loadSettings();
 
 private:
-	int mHist[3][256];
-	int mMaxValue = 20;
+	int mHist[3][256];          /// 3 channels 256 bin. channels duplicated when gray
+	int mNumPixels = 0;         /// image pixel count
+	int mNumDistinctValues = 0; /// number of distinct values
+	int mNumZeroPixels = 0;     /// pixels with zero value
+	int mNumSaturatedPixels = 0;    /// pixels saturating RGB 8bit
+	int mNumValues = 0;         /// number of distinct histogram values
+	int mMinBinValue = 256;     /// (gray-only) minimum intensity value
+	int mMaxBinValue = -1;      /// (gray-only) maximum intensity value
+	int mMaxValue = 20;         /// maximum count over all bins
 	bool mIsPainted = false;
 	float mScaleFactor = 1;
-				
+	DisplayMode mDisplayMode = DisplayMode::histogram_mode_simple; /// determins shown histogram type
+
+	QMenu* mContextMenu = 0;
 };
 
 class DkFileInfo {
@@ -965,14 +989,14 @@ protected:
 	QVector<double> mPoints;
 };
 
-class DllGuiExport DkGenericProfileWidget : public DkNamedWidget {
+class DllCoreExport DkGenericProfileWidget : public DkNamedWidget {
 	Q_OBJECT
 
 public:
-	DkGenericProfileWidget(const QString& name, QWidget* parent);
+	DkGenericProfileWidget(const QString& name, QWidget* parent, const QString& settingsPath = "");
 	virtual ~DkGenericProfileWidget();
 
-	public slots:
+public slots:
 	void saveSettings() const;
 	virtual void saveSettings(const QString& name) const;
 	virtual void loadSettings(const QString& name) = 0;
@@ -994,6 +1018,19 @@ protected:
 	bool mEmpty = true;
 
 	QString mSettingsGroup = "ILLEGAL_GENERIC_GROUP";
+	QString mSettingsPath;
 };
 
+
+class DllCoreExport DkTabEntryWidget : public QPushButton {
+	Q_OBJECT
+
+public:
+	DkTabEntryWidget(const QIcon& icon, const QString& text, QWidget* parent);
+
+protected:
+	void paintEvent(QPaintEvent* event);
+
 };
+
+}
