@@ -52,6 +52,7 @@
 #include <QTextStream>
 #include <QDesktopServices>
 #include <QCommandLineParser>
+#include <QMessageBox>
 #pragma warning(pop)	// no warnings from includes - end
 
 #include "DkNoMacs.h"
@@ -61,6 +62,7 @@
 #include "DkPong.h"
 #include "DkUtils.h"
 #include "DkProcess.h"
+#include "DkPluginManager.h"
 
 #include "DkDependencyResolver.h"
 
@@ -71,9 +73,6 @@
 #include <shlobj.h>
 #endif
 
-void createPluginsPath();
-void computeBatch(const QString& settingsPath, const QString& logPath = QString());
-
 #ifdef Q_OS_WIN
 int main(int argc, wchar_t *argv[]) {
 #else
@@ -83,7 +82,7 @@ int main(int argc, char *argv[]) {
 #ifdef READ_TUWIEN
 	QCoreApplication::setOrganizationName("TU Wien");
 	QCoreApplication::setOrganizationDomain("http://www.nomacs.org");
-	QCoreApplication::setApplicationName("nomacs - Image Lounge [READ]");
+	QCoreApplication::setApplicationName("nomacs [READ]");
 #else
 	QCoreApplication::setOrganizationName("nomacs");
 	QCoreApplication::setOrganizationDomain("http://www.nomacs.org");
@@ -92,21 +91,28 @@ int main(int argc, char *argv[]) {
 	
 	nmc::DkUtils::registerFileVersion();
 
-	QApplication a(argc, (char**)argv);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+    QApplication::setAttribute(Qt::AA_DisableHighDpiScaling, true);
+#endif
+	QApplication app(argc, (char**)argv);
 
 	// init settings
-	nmc::Settings::instance().init();
+	nmc::DkSettingsManager::instance().init();
+	nmc::DefaultSettings settings;
+	int mode = settings.value("AppSettings/appMode", nmc::DkSettingsManager::param().app().appMode).toInt();
 
-	QSettings& settings = nmc::Settings::instance().getSettings();
-	int mode = settings.value("AppSettings/appMode", nmc::Settings::param().app().appMode).toInt();
-
-	//if (!nmc::Settings::param().app().openFilters.empty())
-	//	qInfoClean() << "supported image extensions: " << nmc::Settings::param().app().openFilters[0];
+	// uncomment this for the single instance feature...
+	//// check for single instance
+	//nmc::DkRunGuard guard;
+	//
+	//if (!guard.tryRunning()) {
+	//	qDebug() << "nomacs is already running - quitting...";
+	//	return 0;
+	//}
 
 	// CMD parser --------------------------------------------------------------------
 	QCommandLineParser parser;
-
-	//parser.setApplicationDescription("Test helper");
+	
 	parser.addHelpOption();
 	parser.addVersionOption();
 	parser.addPositionalArgument("image", QObject::tr("An input image."));
@@ -146,12 +152,18 @@ int main(int argc, char *argv[]) {
 		QObject::tr("log-path.txt"));
 	parser.addOption(batchLogOpt);
 
-	parser.process(a);
+	QCommandLineOption importSettingsOpt(QStringList() << "import-settings",
+		QObject::tr("Imports the settings from <settings-path.nfo> and saves them."),
+		QObject::tr("settings-path.nfo"));
+	parser.addOption(importSettingsOpt);
+
+	parser.process(app);
+	
 	// CMD parser --------------------------------------------------------------------
+	nmc::DkPluginManager::createPluginsPath();
 
-	createPluginsPath();
-
-	// load to tabs
+	
+	// compute batch process
 	if (!parser.value(batchOpt).isEmpty()) {
 		
 		QString logPath;
@@ -159,74 +171,74 @@ int main(int argc, char *argv[]) {
 			logPath = parser.value(batchLogOpt);
 
 		QString batchSettingsPath = parser.value(batchOpt);
-		computeBatch(batchSettingsPath, logPath);
+		nmc::DkBatchProcessing::computeBatch(batchSettingsPath, logPath);
+		
 		return 0;
 	}
 
-	//// DEBUG --------------------------------------------------------------------
-	//nmc::DkDependencyWalker dw("C:/VSProjects/READ/nomacs/build2015-x64/Debug/plugins/writerIdentificationPlugin.dll");
-	//if (!dw.findDependencies())
-	//	qWarning() << "could not find dependencies for" << dw.filePath();
+	// apply default settings
+	if (!parser.value(importSettingsOpt).isEmpty()) {
+		QString settingsPath = parser.value(importSettingsOpt);
+		nmc::DkSettingsManager::importSettings(settingsPath);
+		return 0;
+	}
 
-	//qDebug() << "all dependencies:" << dw.dependencies();
-	//qDebug() << "filtered dependencies:" << dw.filteredDependencies();
+	//install translations
+	QString translationName = "nomacs_" + 
+		settings.value("GlobalSettings/language", nmc::DkSettingsManager::param().global().language).toString() + ".qm";
+	QString translationNameQt = "qt_" + 
+		settings.value("GlobalSettings/language", nmc::DkSettingsManager::param().global().language).toString() + ".qm";
 
-	//return 0;
-	//// DEBUG --------------------------------------------------------------------
+	QTranslator translator;
+	nmc::DkSettingsManager::param().loadTranslation(translationName, translator);
+	app.installTranslator(&translator);
+
+	QTranslator translatorQt;
+	nmc::DkSettingsManager::param().loadTranslation(translationNameQt, translatorQt);
+	app.installTranslator(&translatorQt);
 
 	nmc::DkNoMacs* w = 0;
 	nmc::DkPong* pw = 0;	// pong
 
-	QString translationName = "nomacs_"+ settings.value("GlobalSettings/language", nmc::Settings::param().global().language).toString() + ".qm";
-	QString translationNameQt = "qt_"+ settings.value("GlobalSettings/language", nmc::Settings::param().global().language).toString() + ".qm";
-	
-	QTranslator translator;
-	nmc::Settings::param().loadTranslation(translationName, translator);
-	a.installTranslator(&translator);
-	
-	QTranslator translatorQt;
-	nmc::Settings::param().loadTranslation(translationNameQt, translatorQt);
-	a.installTranslator(&translatorQt);
-
 	// show pink icons if nomacs is in private mode
 	if(parser.isSet(privateOpt)) {
-		nmc::Settings::param().display().iconColor = QColor(136, 0, 125);
-		nmc::Settings::param().app().privateMode = true;
+		nmc::DkSettingsManager::param().display().iconColor = QColor(136, 0, 125);
+		nmc::DkSettingsManager::param().app().privateMode = true;
 	}
 
 	if (parser.isSet(modeOpt)) {
-		QString pm = parser.value(modeOpt);// .trimmed();
+		QString pm = parser.value(modeOpt);
 
 		if (pm == "default")
-			mode = nmc::Settings::param().mode_default;
+			mode = nmc::DkSettingsManager::param().mode_default;
 		else if (pm == "frameless")
-			mode = nmc::Settings::param().mode_frameless;
+			mode = nmc::DkSettingsManager::param().mode_frameless;
 		else if (pm == "pseudocolor")
-			mode = nmc::Settings::param().mode_contrast;
+			mode = nmc::DkSettingsManager::param().mode_contrast;
 		else
 			qWarning() << "illegal mode: " << pm << "use either <default>, <frameless> or <pseudocolor>";
 
-		nmc::Settings::param().app().currentAppMode = mode;
+		nmc::DkSettingsManager::param().app().currentAppMode = mode;
 	}
 
 	nmc::DkTimer dt;
 
 	// initialize nomacs
-	if (mode == nmc::Settings::param().mode_frameless) {
-		w = static_cast<nmc::DkNoMacs*> (new nmc::DkNoMacsFrameless());
+	if (mode == nmc::DkSettingsManager::param().mode_frameless) {
+		w = new nmc::DkNoMacsFrameless();
 		qDebug() << "this is the frameless nomacs...";
 	}
-	else if (mode == nmc::Settings::param().mode_contrast) {
-		w = static_cast<nmc::DkNoMacs*> (new nmc::DkNoMacsContrast());
+	else if (mode == nmc::DkSettingsManager::param().mode_contrast) {
+		w = new nmc::DkNoMacsContrast();
 		qDebug() << "this is the contrast nomacs...";
 	}
 	else if (parser.isSet(pongOpt)) {
 		pw = new nmc::DkPong();
-		int rVal = a.exec();
+		int rVal = app.exec();
 		return rVal;
 	}
 	else
-		w = static_cast<nmc::DkNoMacs*> (new nmc::DkNoMacsIpl());	// slice it
+		w = new nmc::DkNoMacsIpl();
 
 	if (w)
 		w->onWindowLoaded();
@@ -234,14 +246,16 @@ int main(int argc, char *argv[]) {
 	qInfo() << "Initialization takes: " << dt;
 
 	if (!parser.positionalArguments().empty()) {
-		w->loadFile(QFileInfo(parser.positionalArguments()[0]).absoluteFilePath());	// update folder + be silent
-		qDebug() << "loading: " << parser.positionalArguments()[0];
-	}
-	else {
-		bool showRecent = nmc::Settings::param().app().showRecentFiles;
-		showRecent &= nmc::Settings::param().app().currentAppMode != nmc::DkSettings::mode_frameless;
-		w->showRecentFiles(showRecent);
+		QString filePath = parser.positionalArguments()[0].trimmed();
+
+		if (!filePath.isEmpty())
+			w->loadFile(QFileInfo(filePath).absoluteFilePath());	// update folder + be silent
 	}
+	//else {
+	//	bool showRecent = nmc::DkSettingsManager::param().app().showRecentFiles;
+	//	showRecent &= nmc::DkSettingsManager::param().app().currentAppMode != nmc::DkSettings::mode_frameless;
+	//	w->showRecentFiles(showRecent);
+	//}
 
 	// load directory preview
 	if (!parser.value(sourceDirOpt).trimmed().isEmpty()) {
@@ -259,11 +273,11 @@ int main(int argc, char *argv[]) {
 			cw->addTab(filePath);
 	}
 
-	int fullScreenMode = settings.value("AppSettings/currentAppMode", nmc::Settings::param().app().currentAppMode).toInt();
+	int fullScreenMode = settings.value("AppSettings/currentAppMode", nmc::DkSettingsManager::param().app().currentAppMode).toInt();
 
-	if (fullScreenMode == nmc::Settings::param().mode_default_fullscreen		||
-		fullScreenMode == nmc::Settings::param().mode_frameless_fullscreen		||
-		fullScreenMode == nmc::Settings::param().mode_contrast_fullscreen		||
+	if (fullScreenMode == nmc::DkSettingsManager::param().mode_default_fullscreen		||
+		fullScreenMode == nmc::DkSettingsManager::param().mode_frameless_fullscreen		||
+		fullScreenMode == nmc::DkSettingsManager::param().mode_contrast_fullscreen		||
 		parser.isSet(fullScreenOpt)) {
 		w->enterFullScreen();
 		qDebug() << "trying to enter fullscreen...";
@@ -271,12 +285,20 @@ int main(int argc, char *argv[]) {
 
 #ifdef Q_WS_MAC
 	nmc::DkNomacsOSXEventFilter *osxEventFilter = new nmc::DkNomacsOSXEventFilter();
-	a.installEventFilter(osxEventFilter);
+	app.installEventFilter(osxEventFilter);
 	QObject::connect(osxEventFilter, SIGNAL(loadFile(const QFileInfo&)),
 		w, SLOT(loadFile(const QFileInfo&)));
 #endif
 
-	int rVal = a.exec();
+	int rVal = -1;
+	try {
+		rVal = app.exec();
+	}
+	catch (const std::bad_alloc&) {
+		
+		QMessageBox::critical(0, QObject::tr("Critical Error"), 
+			QObject::tr("Sorry, nomacs ran out of memory..."), QMessageBox::Ok);
+	}
 
 	if (w)
 		delete w;	// we need delete so that settings are saved (from destructors)
@@ -285,63 +307,3 @@ int main(int argc, char *argv[]) {
 
 	return rVal;
 }
-
-void computeBatch(const QString& settingsPath, const QString& logPath) {
-	
-	nmc::DkBatchConfig bc = nmc::DkBatchProfile::loadProfile(settingsPath);
-
-	// guarantee that the output path exists
-	if (!QDir().mkpath(bc.getOutputDirPath())) {
-		qCritical() << "Could not create:" << bc.getOutputDirPath();
-		return;
-	}
-
-	QSharedPointer<nmc::DkBatchProcessing> process(new nmc::DkBatchProcessing());
-	process->setBatchConfig(bc);
-	process->compute();
-
-	process->waitForFinished();	// block
-
-	if (!logPath.isEmpty()) {
-		
-		QFileInfo fi(logPath);
-		
-		QDir().mkpath(fi.absolutePath());
-
-		QFile file(logPath);
-		if (!file.open(QIODevice::WriteOnly))
-			qWarning() << "Sorry, I could not write to" << logPath;
-		else {
-			QStringList log = process->getLog();
-			QTextStream s(&file);
-			for (const QString& line : log)
-				s << line << '\n';
-			qInfo() << "log written to: " << logPath;
-		}
-	}
-}
-
-void createPluginsPath() {
-
-#ifdef WITH_PLUGINS
-	// initialize plugin paths -----------------------------------------
-#ifdef Q_OS_WIN
-	QDir pluginsDir = QCoreApplication::applicationDirPath() + "/plugins";
-#else
-	QDir pluginsDir = QCoreApplication::applicationDirPath() +  "/../lib/nomacs-plugins/";
-#endif // Q_OS_WIN
-
-
-	if (!pluginsDir.exists())
-		pluginsDir.mkpath(pluginsDir.absolutePath());
-
-	nmc::Settings::param().global().pluginsDir = pluginsDir.absolutePath();
-	qDebug() << "plugins dir set to: " << nmc::Settings::param().global().pluginsDir;
-
-	QCoreApplication::addLibraryPath(nmc::Settings::param().global().pluginsDir);
-
-	QCoreApplication::addLibraryPath("./imageformats");
-
-#endif // WITH_PLUGINS
-
-}
